/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2002 file and create a SAS dataset.                                                    *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\opafy02nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = opafy02nid ;

/***********************************************************************************/
/************** SHOULD NOT NEED TO CHANGE ANYTHING BELOW THIS POINT ****************/
/***********************************************************************************/

DATA library.&dataset ;
INFILE datafile LRECL=18173;
INPUT
   SAFETY $ 1-3             ZONE $ 4                 AMTFINEC  5-11        
   AMTREST  12-20           AMTTOTAL  21-29          COSTSUP  30-36        
   FINE  37-43              TOTREST  44-53           SENTTOT  54-59        
   SENTTOT0  60-65          SENSPLT  66-71           SENSPLT0  72-77       
   TIMESERV  78-84          USSCIDN  85-90           ACCAP  91             
   ACCCAT  92               ACCGDLN  93              ACCOFFLV  94-95       
   ACCTRESP  96-97          CAROFFAP  98             AGE  99-100           
   ALTDUM  101              ALTMO  102-103           AMENDYR  104-107      
   CAROFFLV  108-109        CHAP2  110-111           CIRCDIST  112-113     
   CITIZEN  114             CITWHERE  115-117        COADJLEV  118-119     
   COMBDRG2  120-121        COMDUM  122              COSTSDUM  123         
   CRIMHIST  124            CRIMLIV  125-126         CRIMPTS  127-129      
   DAYSDUM  130             DEFCONSL  131-132        DEPART  133           
   DISPOSIT  134            DISTRICT  135-136        DRUGTYP1  137-139     
   DRUGTYP2  140-142        DRUGTYP3  143-145        DRUGTYP4  146-148     
   DRUGTYP5  149-151        DSIND  152               DSJANDC  153          
   DSPLEA  154              DSPSR  155               DSSOR  156            
   DUFROM1  157-158         DUFROM2  159             DUFROM3  160          
   DUFROM4  161             DUFROM5  162             DUTO1  163-164        
   DUTO2  165               DUTO3  166               DUTO4  167            
   DUTO5  168               ECONDUM  169             EDUCATN  170-171      
   ENCRYPT1  172            ENCRYPT2  173            FINECDUM  174         
   FINEWAIV  175            HISPORIG  176            HOMDUM  177           
   HRCOMSRV  178-181        INOUT  182               INTDUM  183           
   IS924C  184              MARRIED  185             MOCOMCON  186-187     
   MOHOMDET  188-189        MOINTCON  190-191        MONCIRC  192-193      
   MONRACE  194             MONSEX  195              NEWCIT  196           
   NEWCNVTN  197            NEWEDUC  198             NEWRACE  199          
   NOCOMP  200-201          NOCOUNTS  202-204        NOUSTAT  205-206      
   NUMDEPEN  207-208        OFFTYPE2  209-210        POINT1  211           
   POINT2  212-213          POINT3  214-215          PRESENT  216          
   PRISDUM  217             PROBATN  218-220         PROBDUM  221          
   RANGEPT  222             REASON1  223-225         REASON2  226-228      
   REASON3  229-231         REL2PTS  232             RESNTDOC  233-234     
   RESTDUM  235             SAFE  236                SENTIMP  237          
   SENTPTS  238             SEXOFFNA  239-240        SEXOFFNB  241-242     
   SOURCES  243             SUPRDUM  244             SUPREL  245-247       
   TOTCHPTS  248-249        TOTDAYS  250-251         TOTUNIT  252-262      
   TYPEMONY  263            TYPEOTHS  264-265        UNIT1  266-267        
   UNIT2  268-269           UNIT3  270-271           UNIT4  272-273        
   UNIT5  274-275           VIOL1PTS  276            WEAPON  277           
   WEAPSOC  278             XCRHISSR  279            XFOLSOR  280-281      
   YEARS  282               DRUGMIN  283-286         GLMIN  287-290        
   GLMAX  291-294           GUNMIN1  295-298         GUNMIN2  299-301      
   STATMAX  302-306         STATMIN  307-310         TOTPRISN  311-314     
   XMAXSOR  315-318         XMINSOR  319-322         SMIN1  323-326        
   SMIN2  327-330           SMIN3  331-334           SMIN4  335-338        
   SMIN5  339-342           SMIN6  343-346           SMIN7  347-350        
   SMIN8  351-354           SMIN9  355-358           SMIN10  359-362       
   SMIN11  363-366          SMIN12  367-370          SMIN13  371-374       
   SMIN14  375-378          SMIN15  379-382          SMIN16  383-386       
   SMIN17  387-390          SMIN18  391-394          SMIN19  395-398       
   SMIN20  399-402          SMIN21  403-406          SMIN22  407-410       
   SMIN23  411-414          SMIN24  415-418          SMIN25  419-422       
   SMIN26  423-426          SMIN27  427-430          SMIN28  431-434       
   SMIN29  435-438          SMIN30  439-442          SMIN31  443-446       
   SMIN32  447-450          SMIN33  451-454          SMIN34  455-458       
   SMIN35  459-462          SMIN36  463-466          SMIN37  467-470       
   SMIN38  471-474          SMIN39  475-478          SMIN40  479-482       
   SMIN41  483-486          SMIN42  487-490          SMIN43  491-494       
   SMIN44  495-498          SMIN45  499-502          SMIN46  503-506       
   SMIN47  507-510          SMIN48  511-514          SMIN49  515-518       
   SMIN50  519-522          SMIN51  523-526          SMIN52  527-530       
   SMIN53  531-534          SMIN54  535-538          SMIN55  539-542       
   SMIN56  543-546          SMIN57  547-550          SMIN58  551-554       
   SMIN59  555-558          SMIN60  559-562          SMIN61  563-566       
   SMIN62  567-570          SMIN63  571-574          SMIN64  575-578       
   SMIN65  579-582          SMIN66  583-586          SMIN67  587-590       
   SMIN68  591-594          SMIN69  595-598          SMIN70  599-602       
   SMIN71  603-606          SMIN72  607-610          SMIN73  611-614       
   SMIN74  615-618          SMIN75  619-622          SMIN76  623-626       
   SMIN77  627-630          SMIN78  631-634          SMIN79  635-638       
   SMIN80  639-642          SMIN81  643-646          SMIN82  647-650       
   SMIN83  651-654          SMIN84  655-658          SMIN85  659-662       
   SMIN86  663-666          SMIN87  667-670          SMIN88  671-674       
   SMIN89  675-678          SMIN90  679-682          SMIN91  683-686       
   SMIN92  687-690          SMIN93  691-694          SMIN94  695-698       
   SMIN95  699-702          SMIN96  703-706          SMIN97  707-710       
   SMIN98  711-714          SMIN99  715-718          SMIN100  719-722      
   SMIN101  723-726         SMIN102  727-730         SMIN103  731-734      
   SMIN104  735-738         SMIN105  739-742         SMIN106  743-746      
   SMIN107  747-750         SMIN108  751-754         SMIN109  755-758      
   SMIN110  759-762         SMIN111  763-766         SMIN112  767-770      
   SMIN113  771-774         SMIN114  775-778         SMIN115  779-782      
   SMIN116  783-786         SMIN117  787-790         SMIN118  791-794      
   SMIN119  795-798         SMIN120  799-802         SMIN121  803-806      
   SMIN122  807-810         SMIN123  811-814         SMIN124  815-818      
   SMIN125  819-822         SMIN126  823-826         SMIN127  827-830      
   SMIN128  831-834         SMIN129  835-838         SMIN130  839-842      
   SMIN131  843-846         SMIN132  847-850         SMIN133  851-854      
   SMIN134  855-858         SMIN135  859-862         SMIN136  863-866      
   SMIN137  867-870         SMIN138  871-874         SMIN139  875-878      
   SMIN140  879-882         SMIN141  883-886         SMIN142  887-890      
   SMIN143  891-894         SMIN144  895-898         SMIN145  899-902      
   SMIN146  903-906         SMIN147  907-910         SMIN148  911-914      
   SMIN149  915-918         SMIN150  919-922         SMIN151  923-926      
   SMIN152  927-930         SMIN153  931-934         SMIN154  935-938      
   SMIN155  939-942         SMIN156  943-946         SMIN157  947-950      
   SMIN158  951-954         SMIN159  955-958         SMIN160  959-962      
   SMIN161  963-966         SMIN162  967-970         SMIN163  971-974      
   SMIN164  975-978         SMIN165  979-982         SMIN166  983-986      
   SMIN167  987-990         SMIN168  991-994         SMIN169  995-998      
   SMIN170  999-1002        SMIN171  1003-1006       SMIN172  1007-1010    
   SMIN173  1011-1014       SMIN174  1015-1018       SMIN175  1019-1022    
   SMIN176  1023-1026       SMIN177  1027-1030       SMIN178  1031-1034    
   SMIN179  1035-1038       SMIN180  1039-1042       SMIN181  1043-1046    
   SMIN182  1047-1050       SMIN183  1051-1054       SMIN184  1055-1058    
   SMIN185  1059-1062       SMIN186  1063-1066       SMIN187  1067-1070    
   SMIN188  1071-1074       SMIN189  1075-1078       SMIN190  1079-1082    
   SMIN191  1083-1086       SMIN192  1087-1090       SMIN193  1091-1094    
   SMIN194  1095-1098       SMIN195  1099-1102       SMIN196  1103-1106    
   SMIN197  1107-1110       SMIN198  1111-1114       SMIN199  1115-1118    
   SMIN200  1119-1122       SMIN201  1123-1126       SMIN202  1127-1130    
   SMIN203  1131-1134       SMIN204  1135-1138       SMIN205  1139-1142    
   SMIN206  1143-1146       SMIN207  1147-1150       SMIN208  1151-1154    
   SMIN209  1155-1158       SMIN210  1159-1162       SMIN211  1163-1166    
   SMIN212  1167-1170       SMIN213  1171-1174       SMIN214  1175-1178    
   SMIN215  1179-1182       SMIN216  1183-1186       SMIN217  1187-1190    
   SMIN218  1191-1194       SMIN219  1195-1198       SMIN220  1199-1202    
   SMIN221  1203-1206       SMIN222  1207-1210       SMIN223  1211-1214    
   SMIN224  1215-1218       SMIN225  1219-1222       SMIN226  1223-1226    
   SMIN227  1227-1230       SMIN228  1231-1234       SMIN229  1235-1238    
   SMIN230  1239-1242       SMIN231  1243-1246       SMIN232  1247-1250    
   SMIN233  1251-1254       SMIN234  1255-1258       SMIN235  1259-1262    
   SMIN236  1263-1266       SMIN237  1267-1270       SMIN238  1271-1274    
   SMIN239  1275-1278       SMIN240  1279-1282       SMIN241  1283-1286    
   SMIN242  1287-1290       SMIN243  1291-1294       SMIN244  1295-1298    
   SMIN245  1299-1302       SMIN246  1303-1306       SMIN247  1307-1310    
   SMIN248  1311-1314       SMIN249  1315-1318       SMIN250  1319-1322    
   SMIN251  1323-1326       SMIN252  1327-1330       SMIN253  1331-1334    
   SMIN254  1335-1338       SMIN255  1339-1342       SMIN256  1343-1346    
   SMIN257  1347-1350       SMIN258  1351-1354       SMIN259  1355-1358    
   SMIN260  1359-1362       SMIN261  1363-1366       SMIN262  1367-1370    
   SMIN263  1371-1374       SMIN264  1375-1378       SMIN265  1379-1382    
   SMIN266  1383-1386       SMAX1  1387-1390         SMAX2  1391-1394      
   SMAX3  1395-1398         SMAX4  1399-1402         SMAX5  1403-1406      
   SMAX6  1407-1410         SMAX7  1411-1414         SMAX8  1415-1418      
   SMAX9  1419-1422         SMAX10  1423-1426        SMAX11  1427-1430     
   SMAX12  1431-1434        SMAX13  1435-1438        SMAX14  1439-1442     
   SMAX15  1443-1446        SMAX16  1447-1450        SMAX17  1451-1454     
   SMAX18  1455-1458        SMAX19  1459-1462        SMAX20  1463-1466     
   SMAX21  1467-1470        SMAX22  1471-1474        SMAX23  1475-1478     
   SMAX24  1479-1482        SMAX25  1483-1486        SMAX26  1487-1490     
   SMAX27  1491-1494        SMAX28  1495-1498        SMAX29  1499-1502     
   SMAX30  1503-1506        SMAX31  1507-1510        SMAX32  1511-1514     
   SMAX33  1515-1518        SMAX34  1519-1522        SMAX35  1523-1526     
   SMAX36  1527-1530        SMAX37  1531-1534        SMAX38  1535-1538     
   SMAX39  1539-1542        SMAX40  1543-1546        SMAX41  1547-1550     
   SMAX42  1551-1554        SMAX43  1555-1558        SMAX44  1559-1562     
   SMAX45  1563-1566        SMAX46  1567-1570        SMAX47  1571-1574     
   SMAX48  1575-1578        SMAX49  1579-1582        SMAX50  1583-1586     
   SMAX51  1587-1590        SMAX52  1591-1594        SMAX53  1595-1598     
   SMAX54  1599-1602        SMAX55  1603-1606        SMAX56  1607-1610     
   SMAX57  1611-1614        SMAX58  1615-1618        SMAX59  1619-1622     
   SMAX60  1623-1626        SMAX61  1627-1630        SMAX62  1631-1634     
   SMAX63  1635-1638        SMAX64  1639-1642        SMAX65  1643-1646     
   SMAX66  1647-1650        SMAX67  1651-1654        SMAX68  1655-1658     
   SMAX69  1659-1662        SMAX70  1663-1666        SMAX71  1667-1670     
   SMAX72  1671-1674        SMAX73  1675-1678        SMAX74  1679-1682     
   SMAX75  1683-1686        SMAX76  1687-1690        SMAX77  1691-1694     
   SMAX78  1695-1698        SMAX79  1699-1702        SMAX80  1703-1706     
   SMAX81  1707-1710        SMAX82  1711-1714        SMAX83  1715-1718     
   SMAX84  1719-1722        SMAX85  1723-1726        SMAX86  1727-1730     
   SMAX87  1731-1734        SMAX88  1735-1738        SMAX89  1739-1742     
   SMAX90  1743-1746        SMAX91  1747-1750        SMAX92  1751-1754     
   SMAX93  1755-1758        SMAX94  1759-1762        SMAX95  1763-1766     
   SMAX96  1767-1770        SMAX97  1771-1774        SMAX98  1775-1778     
   SMAX99  1779-1782        SMAX100  1783-1786       SMAX101  1787-1790    
   SMAX102  1791-1794       SMAX103  1795-1798       SMAX104  1799-1802    
   SMAX105  1803-1806       SMAX106  1807-1810       SMAX107  1811-1814    
   SMAX108  1815-1818       SMAX109  1819-1822       SMAX110  1823-1826    
   SMAX111  1827-1830       SMAX112  1831-1834       SMAX113  1835-1838    
   SMAX114  1839-1842       SMAX115  1843-1846       SMAX116  1847-1850    
   SMAX117  1851-1854       SMAX118  1855-1858       SMAX119  1859-1862    
   SMAX120  1863-1866       SMAX121  1867-1870       SMAX122  1871-1874    
   SMAX123  1875-1878       SMAX124  1879-1882       SMAX125  1883-1886    
   SMAX126  1887-1890       SMAX127  1891-1894       SMAX128  1895-1898    
   SMAX129  1899-1902       SMAX130  1903-1906       SMAX131  1907-1910    
   SMAX132  1911-1914       SMAX133  1915-1918       SMAX134  1919-1922    
   SMAX135  1923-1926       SMAX136  1927-1930       SMAX137  1931-1934    
   SMAX138  1935-1938       SMAX139  1939-1942       SMAX140  1943-1946    
   SMAX141  1947-1950       SMAX142  1951-1954       SMAX143  1955-1958    
   SMAX144  1959-1962       SMAX145  1963-1966       SMAX146  1967-1970    
   SMAX147  1971-1974       SMAX148  1975-1978       SMAX149  1979-1982    
   SMAX150  1983-1986       SMAX151  1987-1990       SMAX152  1991-1994    
   SMAX153  1995-1998       SMAX154  1999-2002       SMAX155  2003-2006    
   SMAX156  2007-2010       SMAX157  2011-2014       SMAX158  2015-2018    
   SMAX159  2019-2022       SMAX160  2023-2026       SMAX161  2027-2030    
   SMAX162  2031-2034       SMAX163  2035-2038       SMAX164  2039-2042    
   SMAX165  2043-2046       SMAX166  2047-2050       SMAX167  2051-2054    
   SMAX168  2055-2058       SMAX169  2059-2062       SMAX170  2063-2066    
   SMAX171  2067-2070       SMAX172  2071-2074       SMAX173  2075-2078    
   SMAX174  2079-2082       SMAX175  2083-2086       SMAX176  2087-2090    
   SMAX177  2091-2094       SMAX178  2095-2098       SMAX179  2099-2102    
   SMAX180  2103-2106       SMAX181  2107-2110       SMAX182  2111-2114    
   SMAX183  2115-2118       SMAX184  2119-2122       SMAX185  2123-2126    
   SMAX186  2127-2130       SMAX187  2131-2134       SMAX188  2135-2138    
   SMAX189  2139-2142       SMAX190  2143-2146       SMAX191  2147-2150    
   SMAX192  2151-2154       SMAX193  2155-2158       SMAX194  2159-2162    
   SMAX195  2163-2166       SMAX196  2167-2170       SMAX197  2171-2174    
   SMAX198  2175-2178       SMAX199  2179-2182       SMAX200  2183-2186    
   SMAX201  2187-2190       SMAX202  2191-2194       SMAX203  2195-2198    
   SMAX204  2199-2202       SMAX205  2203-2206       SMAX206  2207-2210    
   SMAX207  2211-2214       SMAX208  2215-2218       SMAX209  2219-2222    
   SMAX210  2223-2226       SMAX211  2227-2230       SMAX212  2231-2234    
   SMAX213  2235-2238       SMAX214  2239-2242       SMAX215  2243-2246    
   SMAX216  2247-2250       SMAX217  2251-2254       SMAX218  2255-2258    
   SMAX219  2259-2262       SMAX220  2263-2266       SMAX221  2267-2270    
   SMAX222  2271-2274       SMAX223  2275-2278       SMAX224  2279-2282    
   SMAX225  2283-2286       SMAX226  2287-2290       SMAX227  2291-2294    
   SMAX228  2295-2298       SMAX229  2299-2302       SMAX230  2303-2306    
   SMAX231  2307-2310       SMAX232  2311-2314       SMAX233  2315-2318    
   SMAX234  2319-2322       SMAX235  2323-2326       SMAX236  2327-2330    
   SMAX237  2331-2334       SMAX238  2335-2338       SMAX239  2339-2342    
   SMAX240  2343-2346       SMAX241  2347-2350       SMAX242  2351-2354    
   SMAX243  2355-2358       SMAX244  2359-2362       SMAX245  2363-2366    
   SMAX246  2367-2370       SMAX247  2371-2374       SMAX248  2375-2378    
   SMAX249  2379-2382       SMAX250  2383-2386       SMAX251  2387-2390    
   SMAX252  2391-2394       SMAX253  2395-2398       SMAX254  2399-2402    
   SMAX255  2403-2406       SMAX256  2407-2410       SMAX257  2411-2414    
   SMAX258  2415-2418       SMAX259  2419-2422       SMAX260  2423-2426    
   SMAX261  2427-2430       SMAX262  2431-2434       SMAX263  2435-2438    
   SMAX264  2439-2442       SMAX265  2443-2446       SMAX266  2447-2450    
   DESCRIP1 $ 2451-2481     DESCRIP2 $ 2482-2495     DESCRIP3 $ 2496-2519  
   DESCRIP4 $ 2520-2562     DESCRIP5 $ 2563          CDESCRIP1 $ 2564      
   CDESCRIP2 $ 2565         CDESCRIP3 $ 2566         CDESCRIP4 $ 2567      
   CDESCRIP5 $ 2568         ABERTXT $ 2569-2618      REASTXT1 $ 2619-2716  
   REASTXT2 $ 2717-2814     REASTXT3 $ 2815-2854     POOFFICE $ 2855       
   TIMSERVD  2856-2858      TIMSERVM  2859-2861      SPECASSM  2862-2866   
   ABERCASE $ 2867          CHMAM1  2868-2874        CHMAM2  2875-2878     
   CHMAM3  2879             CHMAM4  2880             CHMAM5  2881          
   CUNIT1  2882             CUNIT2  2883             CUNIT3  2884          
   CUNIT4  2885             CUNIT5  2886             CHEMTYP1  2887-2888   
   CHEMTYP2  2889-2890      CHEMTYP3  2891           CHEMTYP4  2892        
   CHEMTYP5  2893           CAFROM1  2894-2896       CAFROM2  2897         
   CAFROM3  2898            CAFROM4  2899            CAFROM5  2900         
   CATO1  2901-2903         CATO2  2904              CATO3  2905           
   CATO4  2906              CATO5  2907              SENTDATE DATE11.      
   DOB DATE11.              ABUS1  2930-2931         ABUS2  2932           
   ABUS3  2933              ABUS4  2934              ABUS5  2935           
   ABUS6  2936              ABUS7  2937              ABUS8  2938           
   ABUS9  2939              ABUS10  2940             ABUS11  2941          
   ABUS12  2942             ABUS13  2943             ABUS14  2944          
   ABUS15  2945             ABUS16  2946             ABUS17  2947          
   ABUS18  2948             ABUS19  2949             ABUS20  2950          
   ABUS21  2951             ABUS22  2952             ABUS23  2953          
   ABUS24  2954             ABUS25  2955             ABUS26  2956          
   ABUS27  2957             ABUSHI  2958-2959        ABUSR1  2960-2961     
   ABUSR2  2962             ABUSR3  2963             ABUSR4  2964          
   ABUSR5  2965             ABUSR6  2966             ABUSR7  2967          
   ABUSR8  2968             ABUSR9  2969             ABUSR10  2970         
   ABUSR11  2971            ABUSR12  2972            ABUSR13  2973         
   ABUSR14  2974            ABUSR15  2975            ABUSR16  2976         
   ABUSR17  2977            ABUSR18  2978            ABUSR19  2979         
   ABUSR20  2980            ABUSR21  2981            ABUSR22  2982         
   ABUSR23  2983            ABUSR24  2984            ABUSR25  2985         
   ABUSR26  2986            ABUSR27  2987            ABUSRHI  2988-2989    
   ADJOFL1  2990-2991       ADJOFL2  2992-2993       ADJOFL3  2994-2995    
   ADJOFL4  2996-2997       ADJOFL5  2998-2999       ADJOFL6  3000-3001    
   ADJOFL7  3002-3003       ADJOFL8  3004-3005       ADJOFL9  3006-3007    
   ADJOFL10  3008-3009      ADJOFL11  3010-3011      ADJOFL12  3012-3013   
   ADJOFL13  3014-3015      ADJOFL14  3016-3017      ADJOFL15  3018-3019   
   ADJOFL16  3020-3021      ADJOFL17  3022-3023      ADJOFL18  3024-3025   
   ADJOFL19  3026-3027      ADJOFL20  3028-3029      ADJOFL21  3030-3031   
   ADJOFL22  3032-3033      ADJOFL23  3034-3035      ADJOFL24  3036-3037   
   ADJOFL25  3038-3039      ADJOFL26  3040-3041      ADJOFL27  3042-3043   
   ADJOFLHI  3044-3045      ADJOFR1  3046-3047       ADJOFR2  3048-3049    
   ADJOFR3  3050-3051       ADJOFR4  3052-3053       ADJOFR5  3054-3055    
   ADJOFR6  3056-3057       ADJOFR7  3058-3059       ADJOFR8  3060-3061    
   ADJOFR9  3062-3063       ADJOFR10  3064-3065      ADJOFR11  3066-3067   
   ADJOFR12  3068-3069      ADJOFR13  3070-3071      ADJOFR14  3072-3073   
   ADJOFR15  3074-3075      ADJOFR16  3076-3077      ADJOFR17  3078-3079   
   ADJOFR18  3080-3081      ADJOFR19  3082-3083      ADJOFR20  3084-3085   
   ADJOFR21  3086-3087      ADJOFR22  3088-3089      ADJOFR23  3090-3091   
   ADJOFR24  3092           ADJOFR25  3093-3094      ADJOFR26  3095        
   ADJOFR27  3096-3097      ADJOFRHI  3098-3099      ADJR_B1  3100-3101    
   ADJR_B2  3102-3103       ADJR_B3  3104-3105       ADJR_B4  3106-3107    
   ADJR_B5  3108-3109       ADJR_B6  3110-3111       ADJR_B7  3112         
   ADJR_B8  3113            ADJR_B9  3114            ADJR_B10  3115        
   ADJR_B11  3116           ADJR_B12  3117           ADJR_B13  3118        
   ADJR_B14  3119           ADJR_B15  3120           ADJR_B16  3121        
   ADJR_B17  3122           ADJR_B18  3123           ADJR_B19  3124        
   ADJR_B20  3125           ADJR_B21  3126           ADJR_B22  3127        
   ADJR_B23  3128           ADJR_B24  3129           ADJR_B25  3130        
   ADJR_B26  3131           ADJR_B27  3132           ADJR_BHI  3133-3134   
   ADJR_C1  3135-3137       ADJR_C2  3138-3139       ADJR_C3  3140         
   ADJR_C4  3141            ADJR_C5  3142            ADJR_C6  3143         
   ADJR_C7  3144            ADJR_C8  3145            ADJR_C9  3146         
   ADJR_C10  3147           ADJR_C11  3148           ADJR_C12  3149        
   ADJR_C13  3150           ADJR_C14  3151           ADJR_C15  3152        
   ADJR_C16  3153           ADJR_C17  3154           ADJR_C18  3155        
   ADJR_C19  3156           ADJR_C20  3157           ADJR_C21  3158        
   ADJR_C22  3159           ADJR_C23  3160           ADJR_C24  3161        
   ADJR_C25  3162           ADJR_C26  3163           ADJR_C27  3164        
   ADJR_CHI  3165-3167      ADJR_D1  3168-3169       ADJR_D2  3170         
   ADJR_D3  3171            ADJR_D4  3172            ADJR_D5  3173         
   ADJR_D6  3174            ADJR_D7  3175            ADJR_D8  3176         
   ADJR_D9  3177            ADJR_D10  3178           ADJR_D11  3179        
   ADJR_D12  3180           ADJR_D13  3181           ADJR_D14  3182        
   ADJR_D15  3183           ADJR_D16  3184           ADJR_D17  3185        
   ADJR_D18  3186           ADJR_D19  3187           ADJR_D20  3188        
   ADJR_D21  3189           ADJR_D22  3190           ADJR_D23  3191        
   ADJR_D24  3192           ADJR_D25  3193           ADJR_D26  3194        
   ADJR_D27  3195           ADJR_DHI  3196-3197      ADJR_E1  3198-3199    
   ADJR_E2  3200-3201       ADJR_E3  3202            ADJR_E4  3203         
   ADJR_E5  3204            ADJR_E6  3205            ADJR_E7  3206         
   ADJR_E8  3207            ADJR_E9  3208            ADJR_E10  3209        
   ADJR_E11  3210           ADJR_E12  3211           ADJR_E13  3212        
   ADJR_E14  3213           ADJR_E15  3214           ADJR_E16  3215        
   ADJR_E17  3216           ADJR_E18  3217           ADJR_E19  3218        
   ADJR_E20  3219           ADJR_E21  3220           ADJR_E22  3221        
   ADJR_E23  3222           ADJR_E24  3223           ADJR_E25  3224        
   ADJR_E26  3225           ADJR_E27  3226           ADJR_EHI  3227-3228   
   ADJR_F1  3229            ADJR_F2  3230            ADJR_F3  3231         
   ADJR_F4  3232            ADJR_F5  3233            ADJR_F6  3234         
   ADJR_F7  3235            ADJR_F8  3236            ADJR_F9  3237         
   ADJR_F10  3238           ADJR_F11  3239           ADJR_F12  3240        
   ADJR_F13  3241           ADJR_F14  3242           ADJR_F15  3243        
   ADJR_F16  3244           ADJR_F17  3245           ADJR_F18  3246        
   ADJR_F19  3247           ADJR_F20  3248           ADJR_F21  3249        
   ADJR_F22  3250           ADJR_F23  3251           ADJR_F24  3252        
   ADJR_F25  3253           ADJR_F26  3254           ADJR_F27  3255        
   ADJR_FHI  3256           ADJR_G1  3257-3258       ADJR_G2  3259-3260    
   ADJR_G3  3261            ADJR_G4  3262            ADJR_G5  3263         
   ADJR_G6  3264            ADJR_G7  3265            ADJR_G8  3266         
   ADJR_G9  3267            ADJR_G10  3268           ADJR_G11  3269        
   ADJR_G12  3270           ADJR_G13  3271           ADJR_G14  3272        
   ADJR_G15  3273           ADJR_G16  3274           ADJR_G17  3275        
   ADJR_G18  3276           ADJR_G19  3277           ADJR_G20  3278        
   ADJR_G21  3279           ADJR_G22  3280           ADJR_G23  3281        
   ADJR_G24  3282           ADJR_G25  3283           ADJR_G26  3284        
   ADJR_G27  3285           ADJR_GHI  3286-3287      ADJR_H1  3288-3289    
   ADJR_H2  3290-3291       ADJR_H3  3292            ADJR_H4  3293         
   ADJR_H5  3294            ADJR_H6  3295            ADJR_H7  3296         
   ADJR_H8  3297            ADJR_H9  3298            ADJR_H10  3299        
   ADJR_H11  3300           ADJR_H12  3301           ADJR_H13  3302        
   ADJR_H14  3303           ADJR_H15  3304           ADJR_H16  3305        
   ADJR_H17  3306           ADJR_H18  3307           ADJR_H19  3308        
   ADJR_H20  3309           ADJR_H21  3310           ADJR_H22  3311        
   ADJR_H23  3312           ADJR_H24  3313           ADJR_H25  3314        
   ADJR_H26  3315           ADJR_H27  3316           ADJR_HHI  3317-3318   
   ADJR_I1  3319            ADJR_I2  3320            ADJR_I3  3321         
   ADJR_I4  3322            ADJR_I5  3323            ADJR_I6  3324         
   ADJR_I7  3325            ADJR_I8  3326            ADJR_I9  3327         
   ADJR_I10  3328           ADJR_I11  3329           ADJR_I12  3330        
   ADJR_I13  3331           ADJR_I14  3332           ADJR_I15  3333        
   ADJR_I16  3334           ADJR_I17  3335           ADJR_I18  3336        
   ADJR_I19  3337           ADJR_I20  3338           ADJR_I21  3339        
   ADJR_I22  3340           ADJR_I23  3341           ADJR_I24  3342        
   ADJR_I25  3343           ADJR_I26  3344           ADJR_I27  3345        
   ADJR_IHI  3346           ADJR_J1  3347            ADJR_J2  3348         
   ADJR_J3  3349            ADJR_J4  3350            ADJR_J5  3351         
   ADJR_J6  3352            ADJR_J7  3353            ADJR_J8  3354         
   ADJR_J9  3355            ADJR_J10  3356           ADJR_J11  3357        
   ADJR_J12  3358           ADJR_J13  3359           ADJR_J14  3360        
   ADJR_J15  3361           ADJR_J16  3362           ADJR_J17  3363        
   ADJR_J18  3364           ADJR_J19  3365           ADJR_J20  3366        
   ADJR_J21  3367           ADJR_J22  3368           ADJR_J23  3369        
   ADJR_J24  3370           ADJR_J25  3371           ADJR_J26  3372        
   ADJR_J27  3373           ADJR_JHI  3374           ADJR_K1  3375         
   ADJR_K2  3376            ADJR_K3  3377            ADJR_K4  3378         
   ADJR_K5  3379            ADJR_K6  3380            ADJR_K7  3381         
   ADJR_K8  3382            ADJR_K9  3383            ADJR_K10  3384        
   ADJR_K11  3385           ADJR_K12  3386           ADJR_K13  3387        
   ADJR_K14  3388           ADJR_K15  3389           ADJR_K16  3390        
   ADJR_K17  3391           ADJR_K18  3392           ADJR_K19  3393        
   ADJR_K20  3394           ADJR_K21  3395           ADJR_K22  3396        
   ADJR_K23  3397           ADJR_K24  3398           ADJR_K25  3399        
   ADJR_K26  3400           ADJR_K27  3401           ADJR_KHI  3402        
   ADJR_L1  3403            ADJR_L2  3404            ADJR_L3  3405         
   ADJR_L4  3406            ADJR_L5  3407            ADJR_L6  3408         
   ADJR_L7  3409            ADJR_L8  3410            ADJR_L9  3411         
   ADJR_L10  3412           ADJR_L11  3413           ADJR_L12  3414        
   ADJR_L13  3415           ADJR_L14  3416           ADJR_L15  3417        
   ADJR_L16  3418           ADJR_L17  3419           ADJR_L18  3420        
   ADJR_L19  3421           ADJR_L20  3422           ADJR_L21  3423        
   ADJR_L22  3424           ADJR_L23  3425           ADJR_L24  3426        
   ADJR_L25  3427           ADJR_L26  3428           ADJR_L27  3429        
   ADJR_LHI  3430           ADJR_M1  3431            ADJR_M2  3432         
   ADJR_M3  3433            ADJR_M4  3434            ADJR_M5  3435         
   ADJR_M6  3436            ADJR_M7  3437            ADJR_M8  3438         
   ADJR_M9  3439            ADJR_M10  3440           ADJR_M11  3441        
   ADJR_M12  3442           ADJR_M13  3443           ADJR_M14  3444        
   ADJR_M15  3445           ADJR_M16  3446           ADJR_M17  3447        
   ADJR_M18  3448           ADJR_M19  3449           ADJR_M20  3450        
   ADJR_M21  3451           ADJR_M22  3452           ADJR_M23  3453        
   ADJR_M24  3454           ADJR_M25  3455           ADJR_M26  3456        
   ADJR_M27  3457           ADJR_MHI  3458           ADJR_N1  3459         
   ADJR_N2  3460            ADJR_N3  3461            ADJR_N4  3462         
   ADJR_N5  3463            ADJR_N6  3464            ADJR_N7  3465         
   ADJR_N8  3466            ADJR_N9  3467            ADJR_N10  3468        
   ADJR_N11  3469           ADJR_N12  3470           ADJR_N13  3471        
   ADJR_N14  3472           ADJR_N15  3473           ADJR_N16  3474        
   ADJR_N17  3475           ADJR_N18  3476           ADJR_N19  3477        
   ADJR_N20  3478           ADJR_N21  3479           ADJR_N22  3480        
   ADJR_N23  3481           ADJR_N24  3482           ADJR_N25  3483        
   ADJR_N26  3484           ADJR_N27  3485           ADJR_NHI  3486        
   ADJR_O1  3487            ADJR_O2  3488            ADJR_O3  3489         
   ADJR_O4  3490            ADJR_O5  3491            ADJR_O6  3492         
   ADJR_O7  3493            ADJR_O8  3494            ADJR_O9  3495         
   ADJR_O10  3496           ADJR_O11  3497           ADJR_O12  3498        
   ADJR_O13  3499           ADJR_O14  3500           ADJR_O15  3501        
   ADJR_O16  3502           ADJR_O17  3503           ADJR_O18  3504        
   ADJR_O19  3505           ADJR_O20  3506           ADJR_O21  3507        
   ADJR_O22  3508           ADJR_O23  3509           ADJR_O24  3510        
   ADJR_O25  3511           ADJR_O26  3512           ADJR_O27  3513        
   ADJR_OHI  3514           ADJR_P1  3515            ADJR_P2  3516         
   ADJR_P3  3517            ADJR_P4  3518            ADJR_P5  3519         
   ADJR_P6  3520            ADJR_P7  3521            ADJR_P8  3522         
   ADJR_P9  3523            ADJR_P10  3524           ADJR_P11  3525        
   ADJR_P12  3526           ADJR_P13  3527           ADJR_P14  3528        
   ADJR_P15  3529           ADJR_P16  3530           ADJR_P17  3531        
   ADJR_P18  3532           ADJR_P19  3533           ADJR_P20  3534        
   ADJR_P21  3535           ADJR_P22  3536           ADJR_P23  3537        
   ADJR_P24  3538           ADJR_P25  3539           ADJR_P26  3540        
   ADJR_P27  3541           ADJR_PHI  3542           ADJ_B1  3543-3544     
   ADJ_B2  3545-3546        ADJ_B3  3547-3548        ADJ_B4  3549-3550     
   ADJ_B5  3551-3552        ADJ_B6  3553-3554        ADJ_B7  3555          
   ADJ_B8  3556             ADJ_B9  3557             ADJ_B10  3558         
   ADJ_B11  3559            ADJ_B12  3560            ADJ_B13  3561         
   ADJ_B14  3562            ADJ_B15  3563            ADJ_B16  3564         
   ADJ_B17  3565            ADJ_B18  3566            ADJ_B19  3567         
   ADJ_B20  3568            ADJ_B21  3569            ADJ_B22  3570         
   ADJ_B23  3571            ADJ_B24  3572            ADJ_B25  3573         
   ADJ_B26  3574            ADJ_B27  3575            ADJ_BHI  3576-3577    
   ADJ_C1  3578-3580        ADJ_C2  3581-3582        ADJ_C3  3583-3584     
   ADJ_C4  3585             ADJ_C5  3586             ADJ_C6  3587          
   ADJ_C7  3588             ADJ_C8  3589             ADJ_C9  3590          
   ADJ_C10  3591            ADJ_C11  3592            ADJ_C12  3593         
   ADJ_C13  3594            ADJ_C14  3595            ADJ_C15  3596         
   ADJ_C16  3597            ADJ_C17  3598            ADJ_C18  3599         
   ADJ_C19  3600            ADJ_C20  3601            ADJ_C21  3602         
   ADJ_C22  3603            ADJ_C23  3604            ADJ_C24  3605         
   ADJ_C25  3606            ADJ_C26  3607            ADJ_C27  3608         
   ADJ_CHI  3609-3611       ADJ_D1  3612-3613        ADJ_D2  3614          
   ADJ_D3  3615             ADJ_D4  3616             ADJ_D5  3617          
   ADJ_D6  3618             ADJ_D7  3619             ADJ_D8  3620          
   ADJ_D9  3621             ADJ_D10  3622            ADJ_D11  3623         
   ADJ_D12  3624            ADJ_D13  3625            ADJ_D14  3626         
   ADJ_D15  3627            ADJ_D16  3628            ADJ_D17  3629         
   ADJ_D18  3630            ADJ_D19  3631            ADJ_D20  3632         
   ADJ_D21  3633            ADJ_D22  3634            ADJ_D23  3635         
   ADJ_D24  3636            ADJ_D25  3637            ADJ_D26  3638         
   ADJ_D27  3639            ADJ_DHI  3640-3641       ADJ_E1  3642-3643     
   ADJ_E2  3644-3645        ADJ_E3  3646-3647        ADJ_E4  3648          
   ADJ_E5  3649             ADJ_E6  3650             ADJ_E7  3651          
   ADJ_E8  3652             ADJ_E9  3653             ADJ_E10  3654-3655    
   ADJ_E11  3656            ADJ_E12  3657-3658       ADJ_E13  3659         
   ADJ_E14  3660            ADJ_E15  3661            ADJ_E16  3662         
   ADJ_E17  3663            ADJ_E18  3664            ADJ_E19  3665         
   ADJ_E20  3666            ADJ_E21  3667            ADJ_E22  3668         
   ADJ_E23  3669            ADJ_E24  3670            ADJ_E25  3671         
   ADJ_E26  3672            ADJ_E27  3673            ADJ_EHI  3674-3675    
   ADJ_F1  3676-3677        ADJ_F2  3678-3679        ADJ_F3  3680          
   ADJ_F4  3681             ADJ_F5  3682             ADJ_F6  3683          
   ADJ_F7  3684             ADJ_F8  3685             ADJ_F9  3686          
   ADJ_F10  3687            ADJ_F11  3688            ADJ_F12  3689         
   ADJ_F13  3690            ADJ_F14  3691            ADJ_F15  3692         
   ADJ_F16  3693            ADJ_F17  3694            ADJ_F18  3695         
   ADJ_F19  3696            ADJ_F20  3697            ADJ_F21  3698         
   ADJ_F22  3699            ADJ_F23  3700            ADJ_F24  3701         
   ADJ_F25  3702            ADJ_F26  3703            ADJ_F27  3704         
   ADJ_FHI  3705-3706       ADJ_G1  3707-3708        ADJ_G2  3709-3710     
   ADJ_G3  3711             ADJ_G4  3712             ADJ_G5  3713          
   ADJ_G6  3714             ADJ_G7  3715             ADJ_G8  3716          
   ADJ_G9  3717             ADJ_G10  3718            ADJ_G11  3719         
   ADJ_G12  3720            ADJ_G13  3721            ADJ_G14  3722         
   ADJ_G15  3723            ADJ_G16  3724            ADJ_G17  3725         
   ADJ_G18  3726            ADJ_G19  3727            ADJ_G20  3728         
   ADJ_G21  3729            ADJ_G22  3730            ADJ_G23  3731         
   ADJ_G24  3732            ADJ_G25  3733            ADJ_G26  3734         
   ADJ_G27  3735            ADJ_GHI  3736-3737       ADJ_H1  3738-3739     
   ADJ_H2  3740-3741        ADJ_H3  3742             ADJ_H4  3743-3744     
   ADJ_H5  3745             ADJ_H6  3746             ADJ_H7  3747          
   ADJ_H8  3748             ADJ_H9  3749             ADJ_H10  3750         
   ADJ_H11  3751            ADJ_H12  3752            ADJ_H13  3753         
   ADJ_H14  3754            ADJ_H15  3755            ADJ_H16  3756         
   ADJ_H17  3757            ADJ_H18  3758            ADJ_H19  3759         
   ADJ_H20  3760            ADJ_H21  3761            ADJ_H22  3762         
   ADJ_H23  3763            ADJ_H24  3764            ADJ_H25  3765         
   ADJ_H26  3766            ADJ_H27  3767            ADJ_HHI  3768-3769    
   ADJ_I1  3770             ADJ_I2  3771             ADJ_I3  3772          
   ADJ_I4  3773             ADJ_I5  3774             ADJ_I6  3775          
   ADJ_I7  3776             ADJ_I8  3777             ADJ_I9  3778          
   ADJ_I10  3779            ADJ_I11  3780            ADJ_I12  3781         
   ADJ_I13  3782            ADJ_I14  3783            ADJ_I15  3784         
   ADJ_I16  3785            ADJ_I17  3786            ADJ_I18  3787         
   ADJ_I19  3788            ADJ_I20  3789            ADJ_I21  3790         
   ADJ_I22  3791            ADJ_I23  3792            ADJ_I24  3793         
   ADJ_I25  3794            ADJ_I26  3795            ADJ_I27  3796         
   ADJ_IHI  3797            ADJ_J1  3798             ADJ_J2  3799          
   ADJ_J3  3800             ADJ_J4  3801             ADJ_J5  3802          
   ADJ_J6  3803             ADJ_J7  3804             ADJ_J8  3805          
   ADJ_J9  3806             ADJ_J10  3807            ADJ_J11  3808         
   ADJ_J12  3809            ADJ_J13  3810            ADJ_J14  3811         
   ADJ_J15  3812            ADJ_J16  3813            ADJ_J17  3814         
   ADJ_J18  3815            ADJ_J19  3816            ADJ_J20  3817         
   ADJ_J21  3818            ADJ_J22  3819            ADJ_J23  3820         
   ADJ_J24  3821            ADJ_J25  3822            ADJ_J26  3823         
   ADJ_J27  3824            ADJ_JHI  3825            ADJ_K1  3826          
   ADJ_K2  3827             ADJ_K3  3828             ADJ_K4  3829          
   ADJ_K5  3830             ADJ_K6  3831             ADJ_K7  3832          
   ADJ_K8  3833             ADJ_K9  3834             ADJ_K10  3835         
   ADJ_K11  3836            ADJ_K12  3837            ADJ_K13  3838         
   ADJ_K14  3839            ADJ_K15  3840            ADJ_K16  3841         
   ADJ_K17  3842            ADJ_K18  3843            ADJ_K19  3844         
   ADJ_K20  3845            ADJ_K21  3846            ADJ_K22  3847         
   ADJ_K23  3848            ADJ_K24  3849            ADJ_K25  3850         
   ADJ_K26  3851            ADJ_K27  3852            ADJ_KHI  3853         
   ADJ_L1  3854             ADJ_L2  3855             ADJ_L3  3856          
   ADJ_L4  3857             ADJ_L5  3858             ADJ_L6  3859          
   ADJ_L7  3860             ADJ_L8  3861             ADJ_L9  3862          
   ADJ_L10  3863            ADJ_L11  3864            ADJ_L12  3865         
   ADJ_L13  3866            ADJ_L14  3867            ADJ_L15  3868         
   ADJ_L16  3869            ADJ_L17  3870            ADJ_L18  3871         
   ADJ_L19  3872            ADJ_L20  3873            ADJ_L21  3874         
   ADJ_L22  3875            ADJ_L23  3876            ADJ_L24  3877         
   ADJ_L25  3878            ADJ_L26  3879            ADJ_L27  3880         
   ADJ_LHI  3881            ADJ_M1  3882-3883        ADJ_M2  3884          
   ADJ_M3  3885             ADJ_M4  3886             ADJ_M5  3887          
   ADJ_M6  3888             ADJ_M7  3889             ADJ_M8  3890          
   ADJ_M9  3891             ADJ_M10  3892            ADJ_M11  3893         
   ADJ_M12  3894            ADJ_M13  3895            ADJ_M14  3896         
   ADJ_M15  3897            ADJ_M16  3898            ADJ_M17  3899         
   ADJ_M18  3900            ADJ_M19  3901            ADJ_M20  3902         
   ADJ_M21  3903            ADJ_M22  3904            ADJ_M23  3905         
   ADJ_M24  3906            ADJ_M25  3907            ADJ_M26  3908         
   ADJ_M27  3909            ADJ_MHI  3910-3911       ADJ_N1  3912          
   ADJ_N2  3913             ADJ_N3  3914             ADJ_N4  3915          
   ADJ_N5  3916             ADJ_N6  3917             ADJ_N7  3918          
   ADJ_N8  3919             ADJ_N9  3920             ADJ_N10  3921         
   ADJ_N11  3922            ADJ_N12  3923            ADJ_N13  3924         
   ADJ_N14  3925            ADJ_N15  3926            ADJ_N16  3927         
   ADJ_N17  3928            ADJ_N18  3929            ADJ_N19  3930         
   ADJ_N20  3931            ADJ_N21  3932            ADJ_N22  3933         
   ADJ_N23  3934            ADJ_N24  3935            ADJ_N25  3936         
   ADJ_N26  3937            ADJ_N27  3938            ADJ_NHI  3939         
   ADJ_O1  3940             ADJ_O2  3941             ADJ_O3  3942          
   ADJ_O4  3943             ADJ_O5  3944             ADJ_O6  3945          
   ADJ_O7  3946             ADJ_O8  3947             ADJ_O9  3948          
   ADJ_O10  3949            ADJ_O11  3950            ADJ_O12  3951         
   ADJ_O13  3952            ADJ_O14  3953            ADJ_O15  3954         
   ADJ_O16  3955            ADJ_O17  3956            ADJ_O18  3957         
   ADJ_O19  3958            ADJ_O20  3959            ADJ_O21  3960         
   ADJ_O22  3961            ADJ_O23  3962            ADJ_O24  3963         
   ADJ_O25  3964            ADJ_O26  3965            ADJ_O27  3966         
   ADJ_OHI  3967            ADJ_P1  3968             ADJ_P2  3969          
   ADJ_P3  3970             ADJ_P4  3971             ADJ_P5  3972          
   ADJ_P6  3973             ADJ_P7  3974             ADJ_P8  3975          
   ADJ_P9  3976             ADJ_P10  3977            ADJ_P11  3978         
   ADJ_P12  3979            ADJ_P13  3980            ADJ_P14  3981         
   ADJ_P15  3982            ADJ_P16  3983            ADJ_P17  3984         
   ADJ_P18  3985            ADJ_P19  3986            ADJ_P20  3987         
   ADJ_P21  3988            ADJ_P22  3989            ADJ_P23  3990         
   ADJ_P24  3991            ADJ_P25  3992            ADJ_P26  3993         
   ADJ_P27  3994            ADJ_PHI  3995            AGGRLR1  3996         
   AGGRLR2  3997            AGGRLR3  3998            AGGRLR4  3999         
   AGGRLR5  4000            AGGRLR6  4001            AGGRLR7  4002         
   AGGRLR8  4003            AGGRLR9  4004            AGGRLR10  4005        
   AGGRLR11  4006           AGGRLR12  4007           AGGRLR13  4008        
   AGGRLR14  4009           AGGRLR15  4010           AGGRLR16  4011        
   AGGRLR17  4012           AGGRLR18  4013           AGGRLR19  4014        
   AGGRLR20  4015           AGGRLR21  4016           AGGRLR22  4017        
   AGGRLR23  4018           AGGRLR24  4019           AGGRLR25  4020        
   AGGRLR26  4021           AGGRLR27  4022           AGGRLRHI  4023        
   AGGROL1  4024            AGGROL2  4025            AGGROL3  4026         
   AGGROL4  4027            AGGROL5  4028            AGGROL6  4029         
   AGGROL7  4030            AGGROL8  4031            AGGROL9  4032         
   AGGROL10  4033           AGGROL11  4034           AGGROL12  4035        
   AGGROL13  4036           AGGROL14  4037           AGGROL15  4038        
   AGGROL16  4039           AGGROL17  4040           AGGROL18  4041        
   AGGROL19  4042           AGGROL20  4043           AGGROL21  4044        
   AGGROL22  4045           AGGROL23  4046           AGGROL24  4047        
   AGGROL25  4048           AGGROL26  4049           AGGROL27  4050        
   AGGROLHI  4051           BASADJ1  4052-4054       BASADJ2  4055-4057    
   BASADJ3  4058-4060       BASADJ4  4061-4062       BASADJ5  4063-4065    
   BASADJ6  4066            BASADJ7  4067-4069       BASADJ8  4070         
   BASADJ9  4071            BASADJ10  4072           BASADJ11  4073        
   BASADJ12  4074           BASADJ13  4075           BASADJ14  4076        
   BASADJ15  4077           BASADJ16  4078           BASADJ17  4079        
   BASADJ18  4080           BASADJ19  4081           BASADJ20  4082        
   BASADJ21  4083           BASADJ22  4084           BASADJ23  4085        
   BASADJ24  4086           BASADJ25  4087           BASADJ26  4088        
   BASADJ27  4089           BASADJHI  4090-4092      BASADR1  4093-4094    
   BASADR2  4095            BASADR3  4096-4097       BASADR4  4098         
   BASADR5  4099            BASADR6  4100            BASADR7  4101         
   BASADR8  4102            BASADR9  4103            BASADR10  4104        
   BASADR11  4105           BASADR12  4106           BASADR13  4107        
   BASADR14  4108           BASADR15  4109           BASADR16  4110        
   BASADR17  4111           BASADR18  4112           BASADR19  4113        
   BASADR20  4114           BASADR21  4115           BASADR22  4116        
   BASADR23  4117           BASADR24  4118           BASADR25  4119        
   BASADR26  4120           BASADR27  4121           BASADRHI  4122-4123   
   BASE1  4124-4125         BASE2  4126-4127         BASE3  4128-4129      
   BASE4  4130-4131         BASE5  4132-4133         BASE6  4134-4135      
   BASE7  4136-4137         BASE8  4138-4139         BASE9  4140-4141      
   BASE10  4142-4143        BASE11  4144-4145        BASE12  4146-4147     
   BASE13  4148-4149        BASE14  4150-4151        BASE15  4152-4153     
   BASE16  4154-4155        BASE17  4156-4157        BASE18  4158-4159     
   BASE19  4160-4161        BASE20  4162-4163        BASE21  4164-4165     
   BASE22  4166-4167        BASE23  4168-4169        BASE24  4170-4171     
   BASE25  4172-4173        BASE26  4174-4175        BASE27  4176-4177     
   BASEHI  4178-4179        BASER1  4180-4181        BASER2  4182-4183     
   BASER3  4184-4185        BASER4  4186-4187        BASER5  4188-4189     
   BASER6  4190-4191        BASER7  4192-4193        BASER8  4194-4195     
   BASER9  4196-4197        BASER10  4198-4199       BASER11  4200-4201    
   BASER12  4202-4203       BASER13  4204-4205       BASER14  4206-4207    
   BASER15  4208-4209       BASER16  4210-4211       BASER17  4212-4213    
   BASER18  4214-4215       BASER19  4216-4217       BASER20  4218-4219    
   BASER21  4220-4221       BASER22  4222-4223       BASER23  4224-4225    
   BASER24  4226            BASER25  4227-4228       BASER26  4229         
   BASER27  4230-4231       BASERHI  4232-4233       FLGHTR1  4234         
   FLGHTR2  4235            FLGHTR3  4236            FLGHTR4  4237         
   FLGHTR5  4238            FLGHTR6  4239            FLGHTR7  4240         
   FLGHTR8  4241            FLGHTR9  4242            FLGHTR10  4243        
   FLGHTR11  4244           FLGHTR12  4245           FLGHTR13  4246        
   FLGHTR14  4247           FLGHTR15  4248           FLGHTR16  4249        
   FLGHTR17  4250           FLGHTR18  4251           FLGHTR19  4252        
   FLGHTR20  4253           FLGHTR21  4254           FLGHTR22  4255        
   FLGHTR23  4256           FLGHTR24  4257           FLGHTR25  4258        
   FLGHTR26  4259           FLGHTR27  4260           FLGHTRHI  4261        
   FLIGHT1  4262            FLIGHT2  4263            FLIGHT3  4264         
   FLIGHT4  4265            FLIGHT5  4266            FLIGHT6  4267         
   FLIGHT7  4268            FLIGHT8  4269            FLIGHT9  4270         
   FLIGHT10  4271           FLIGHT11  4272           FLIGHT12  4273        
   FLIGHT13  4274           FLIGHT14  4275           FLIGHT15  4276        
   FLIGHT16  4277           FLIGHT17  4278           FLIGHT18  4279        
   FLIGHT19  4280           FLIGHT20  4281           FLIGHT21  4282        
   FLIGHT22  4283           FLIGHT23  4284           FLIGHT24  4285        
   FLIGHT25  4286           FLIGHT26  4287           FLIGHT27  4288        
   FLIGHTHI  4289           MITRLR1  4290-4291       MITRLR2  4292-4293    
   MITRLR3  4294-4295       MITRLR4  4296            MITRLR5  4297         
   MITRLR6  4298            MITRLR7  4299            MITRLR8  4300         
   MITRLR9  4301            MITRLR10  4302           MITRLR11  4303        
   MITRLR12  4304           MITRLR13  4305           MITRLR14  4306        
   MITRLR15  4307           MITRLR16  4308           MITRLR17  4309        
   MITRLR18  4310           MITRLR19  4311           MITRLR20  4312        
   MITRLR21  4313           MITRLR22  4314           MITRLR23  4315        
   MITRLR24  4316           MITRLR25  4317           MITRLR26  4318        
   MITRLR27  4319           MITRLRHI  4320-4321      MITROL1  4322-4323    
   MITROL2  4324-4325       MITROL3  4326-4327       MITROL4  4328-4329    
   MITROL5  4330-4331       MITROL6  4332-4333       MITROL7  4334-4335    
   MITROL8  4336-4337       MITROL9  4338            MITROL10  4339        
   MITROL11  4340           MITROL12  4341           MITROL13  4342        
   MITROL14  4343           MITROL15  4344           MITROL16  4345        
   MITROL17  4346           MITROL18  4347           MITROL19  4348        
   MITROL20  4349           MITROL21  4350           MITROL22  4351        
   MITROL23  4352           MITROL24  4353           MITROL25  4354        
   MITROL26  4355           MITROL27  4356           MITROLHI  4357-4358   
   OBSTRC1  4359            OBSTRC2  4360            OBSTRC3  4361         
   OBSTRC4  4362            OBSTRC5  4363            OBSTRC6  4364         
   OBSTRC7  4365            OBSTRC8  4366            OBSTRC9  4367         
   OBSTRC10  4368           OBSTRC11  4369           OBSTRC12  4370        
   OBSTRC13  4371           OBSTRC14  4372           OBSTRC15  4373        
   OBSTRC16  4374           OBSTRC17  4375           OBSTRC18  4376        
   OBSTRC19  4377           OBSTRC20  4378           OBSTRC21  4379        
   OBSTRC22  4380           OBSTRC23  4381           OBSTRC24  4382        
   OBSTRC25  4383           OBSTRC26  4384           OBSTRC27  4385        
   OBSTRCHI  4386           OBSTRR1  4387            OBSTRR2  4388         
   OBSTRR3  4389            OBSTRR4  4390            OBSTRR5  4391         
   OBSTRR6  4392            OBSTRR7  4393            OBSTRR8  4394         
   OBSTRR9  4395            OBSTRR10  4396           OBSTRR11  4397        
   OBSTRR12  4398           OBSTRR13  4399           OBSTRR14  4400        
   OBSTRR15  4401           OBSTRR16  4402           OBSTRR17  4403        
   OBSTRR18  4404           OBSTRR19  4405           OBSTRR20  4406        
   OBSTRR21  4407           OBSTRR22  4408           OBSTRR23  4409        
   OBSTRR24  4410           OBSTRR25  4411           OBSTRR26  4412        
   OBSTRR27  4413           OBSTRRHI  4414           OFFVCR1  4415         
   OFFVCR2  4416            OFFVCR3  4417            OFFVCR4  4418         
   OFFVCR5  4419            OFFVCR6  4420            OFFVCR7  4421         
   OFFVCR8  4422            OFFVCR9  4423            OFFVCR10  4424        
   OFFVCR11  4425           OFFVCR12  4426           OFFVCR13  4427        
   OFFVCR14  4428           OFFVCR15  4429           OFFVCR16  4430        
   OFFVCR17  4431           OFFVCR18  4432           OFFVCR19  4433        
   OFFVCR20  4434           OFFVCR21  4435           OFFVCR22  4436        
   OFFVCR23  4437           OFFVCR24  4438           OFFVCR25  4439        
   OFFVCR26  4440           OFFVCR27  4441           OFFVCRHI  4442        
   OFFVCT1  4443            OFFVCT2  4444            OFFVCT3  4445         
   OFFVCT4  4446            OFFVCT5  4447            OFFVCT6  4448         
   OFFVCT7  4449            OFFVCT8  4450            OFFVCT9  4451         
   OFFVCT10  4452           OFFVCT11  4453           OFFVCT12  4454        
   OFFVCT13  4455           OFFVCT14  4456           OFFVCT15  4457        
   OFFVCT16  4458           OFFVCT17  4459           OFFVCT18  4460        
   OFFVCT19  4461           OFFVCT20  4462           OFFVCT21  4463        
   OFFVCT22  4464           OFFVCT23  4465           OFFVCT24  4466        
   OFFVCT25  4467           OFFVCT26  4468           OFFVCT27  4469        
   OFFVCTHI  4470           RLADJR1  4471            RLADJR2  4472         
   RLADJR3  4473            RLADJR4  4474            RLADJR5  4475         
   RLADJR6  4476            RLADJR7  4477            RLADJR8  4478         
   RLADJR9  4479            RLADJR10  4480           RLADJR11  4481        
   RLADJR12  4482           RLADJR13  4483           RLADJR14  4484        
   RLADJR15  4485           RLADJR16  4486           RLADJR17  4487        
   RLADJR18  4488           RLADJR19  4489           RLADJR20  4490        
   RLADJR21  4491           RLADJR22  4492           RLADJR23  4493        
   RLADJR24  4494           RLADJR25  4495           RLADJR26  4496        
   RLADJR27  4497           RLADJRHI  4498           ROLADJ1  4499         
   ROLADJ2  4500            ROLADJ3  4501            ROLADJ4  4502         
   ROLADJ5  4503            ROLADJ6  4504            ROLADJ7  4505         
   ROLADJ8  4506            ROLADJ9  4507            ROLADJ10  4508        
   ROLADJ11  4509           ROLADJ12  4510           ROLADJ13  4511        
   ROLADJ14  4512           ROLADJ15  4513           ROLADJ16  4514        
   ROLADJ17  4515           ROLADJ18  4516           ROLADJ19  4517        
   ROLADJ20  4518           ROLADJ21  4519           ROLADJ22  4520        
   ROLADJ23  4521           ROLADJ24  4522           ROLADJ25  4523        
   ROLADJ26  4524           ROLADJ27  4525           ROLADJHI  4526        
   RSTRVC1  4527            RSTRVC2  4528            RSTRVC3  4529         
   RSTRVC4  4530            RSTRVC5  4531            RSTRVC6  4532         
   RSTRVC7  4533            RSTRVC8  4534            RSTRVC9  4535         
   RSTRVC10  4536           RSTRVC11  4537           RSTRVC12  4538        
   RSTRVC13  4539           RSTRVC14  4540           RSTRVC15  4541        
   RSTRVC16  4542           RSTRVC17  4543           RSTRVC18  4544        
   RSTRVC19  4545           RSTRVC20  4546           RSTRVC21  4547        
   RSTRVC22  4548           RSTRVC23  4549           RSTRVC24  4550        
   RSTRVC25  4551           RSTRVC26  4552           RSTRVC27  4553        
   RSTRVCHI  4554           RSTRVR1  4555            RSTRVR2  4556         
   RSTRVR3  4557            RSTRVR4  4558            RSTRVR5  4559         
   RSTRVR6  4560            RSTRVR7  4561            RSTRVR8  4562         
   RSTRVR9  4563            RSTRVR10  4564           RSTRVR11  4565        
   RSTRVR12  4566           RSTRVR13  4567           RSTRVR14  4568        
   RSTRVR15  4569           RSTRVR16  4570           RSTRVR17  4571        
   RSTRVR18  4572           RSTRVR19  4573           RSTRVR20  4574        
   RSTRVR21  4575           RSTRVR22  4576           RSTRVR23  4577        
   RSTRVR24  4578           RSTRVR25  4579           RSTRVR26  4580        
   RSTRVR27  4581           RSTRVRHI  4582           TEROR1  4583-4584     
   TEROR2  4585-4586        TEROR3  4587-4588        TEROR4  4589-4590     
   TEROR5  4591-4592        TEROR6  4593-4594        TEROR7  4595-4596     
   TEROR8  4597-4598        TEROR9  4599-4600        TEROR10  4601-4602    
   TEROR11  4603-4604       TEROR12  4605            TEROR13  4606         
   TEROR14  4607            TEROR15  4608            TEROR16  4609         
   TEROR17  4610            TEROR18  4611            TEROR19  4612         
   TEROR20  4613            TEROR21  4614            TEROR22  4615         
   TEROR23  4616            TEROR24  4617            TEROR25  4618         
   TEROR26  4619            TEROR27  4620            TERORHI  4621-4622    
   TERORR1  4623-4624       TERORR2  4625            TERORR3  4626-4627    
   TERORR4  4628            TERORR5  4629            TERORR6  4630         
   TERORR7  4631            TERORR8  4632            TERORR9  4633         
   TERORR10  4634           TERORR11  4635           TERORR12  4636        
   TERORR13  4637           TERORR14  4638           TERORR15  4639        
   TERORR16  4640           TERORR17  4641           TERORR18  4642        
   TERORR19  4643           TERORR20  4644           TERORR21  4645        
   TERORR22  4646           TERORR23  4647           TERORR24  4648        
   TERORR25  4649           TERORR26  4650           TERORR27  4651        
   TERORRHI  4652-4653      USKID1  4654             USKID2  4655          
   USKID3  4656             USKID4  4657             USKID5  4658          
   USKID6  4659             USKID7  4660             USKID8  4661          
   USKID9  4662             USKID10  4663            USKID11  4664         
   USKID12  4665            USKID13  4666            USKID14  4667         
   USKID15  4668            USKID16  4669            USKID17  4670         
   USKID18  4671            USKID19  4672            USKID20  4673         
   USKID21  4674            USKID22  4675            USKID23  4676         
   USKID24  4677            USKID25  4678            USKID26  4679         
   USKID27  4680            USKIDHI  4681            USKIDR1  4682         
   USKIDR2  4683            USKIDR3  4684            USKIDR4  4685         
   USKIDR5  4686            USKIDR6  4687            USKIDR7  4688         
   USKIDR8  4689            USKIDR9  4690            USKIDR10  4691        
   USKIDR11  4692           USKIDR12  4693           USKIDR13  4694        
   USKIDR14  4695           USKIDR15  4696           USKIDR16  4697        
   USKIDR17  4698           USKIDR18  4699           USKIDR19  4700        
   USKIDR20  4701           USKIDR21  4702           USKIDR22  4703        
   USKIDR23  4704           USKIDR24  4705           USKIDR25  4706        
   USKIDR26  4707           USKIDR27  4708           USKIDRHI  4709        
   VCADJR1  4710            VCADJR2  4711            VCADJR3  4712         
   VCADJR4  4713            VCADJR5  4714            VCADJR6  4715         
   VCADJR7  4716            VCADJR8  4717            VCADJR9  4718         
   VCADJR10  4719           VCADJR11  4720           VCADJR12  4721        
   VCADJR13  4722           VCADJR14  4723           VCADJR15  4724        
   VCADJR16  4725           VCADJR17  4726           VCADJR18  4727        
   VCADJR19  4728           VCADJR20  4729           VCADJR21  4730        
   VCADJR22  4731           VCADJR23  4732           VCADJR24  4733        
   VCADJR25  4734           VCADJR26  4735           VCADJR27  4736        
   VCADJRHI  4737           VCTADJ1  4738            VCTADJ2  4739         
   VCTADJ3  4740            VCTADJ4  4741            VCTADJ5  4742         
   VCTADJ6  4743            VCTADJ7  4744            VCTADJ8  4745         
   VCTADJ9  4746            VCTADJ10  4747           VCTADJ11  4748        
   VCTADJ12  4749           VCTADJ13  4750           VCTADJ14  4751        
   VCTADJ15  4752           VCTADJ16  4753           VCTADJ17  4754        
   VCTADJ18  4755           VCTADJ19  4756           VCTADJ20  4757        
   VCTADJ21  4758           VCTADJ22  4759           VCTADJ23  4760        
   VCTADJ24  4761           VCTADJ25  4762           VCTADJ26  4763        
   VCTADJ27  4764           VCTADJHI  4765           VULVCR1  4766         
   VULVCR2  4767            VULVCR3  4768            VULVCR4  4769         
   VULVCR5  4770            VULVCR6  4771            VULVCR7  4772         
   VULVCR8  4773            VULVCR9  4774            VULVCR10  4775        
   VULVCR11  4776           VULVCR12  4777           VULVCR13  4778        
   VULVCR14  4779           VULVCR15  4780           VULVCR16  4781        
   VULVCR17  4782           VULVCR18  4783           VULVCR19  4784        
   VULVCR20  4785           VULVCR21  4786           VULVCR22  4787        
   VULVCR23  4788           VULVCR24  4789           VULVCR25  4790        
   VULVCR26  4791           VULVCR27  4792           VULVCRHI  4793        
   VULVCT1  4794            VULVCT2  4795            VULVCT3  4796         
   VULVCT4  4797            VULVCT5  4798            VULVCT6  4799         
   VULVCT7  4800            VULVCT8  4801            VULVCT9  4802         
   VULVCT10  4803           VULVCT11  4804           VULVCT12  4805        
   VULVCT13  4806           VULVCT14  4807           VULVCT15  4808        
   VULVCT16  4809           VULVCT17  4810           VULVCT18  4811        
   VULVCT19  4812           VULVCT20  4813           VULVCT21  4814        
   VULVCT22  4815           VULVCT23  4816           VULVCT24  4817        
   VULVCT25  4818           VULVCT26  4819           VULVCT27  4820        
   VULVCTHI  4821           GDLINE1 $ 4822-4827      GDLINE2 $ 4828-4833   
   GDLINE3 $ 4834-4839      GDLINE4 $ 4840-4844      GDLINE5 $ 4845-4849   
   GDLINE6 $ 4850-4854      GDLINE7 $ 4855-4859      GDLINE8 $ 4860-4864   
   GDLINE9 $ 4865-4869      GDLINE10 $ 4870-4874     GDLINE11 $ 4875-4879  
   GDLINE12 $ 4880-4884     GDLINE13 $ 4885-4889     GDLINE14 $ 4890-4894  
   GDLINE15 $ 4895-4899     GDLINE16 $ 4900-4904     GDLINE17 $ 4905-4909  
   GDLINE18 $ 4910-4914     GDLINE19 $ 4915-4919     GDLINE20 $ 4920-4924  
   GDLINE21 $ 4925-4929     GDLINE22 $ 4930-4934     GDLINE23 $ 4935-4939  
   GDLINE24 $ 4940-4944     GDLINE25 $ 4945-4949     GDLINE26 $ 4950-4954  
   GDLINE27 $ 4955-4959     GDSTAT1 $ 4960-4965      GDSTAT2 $ 4966-4971   
   GDSTAT3 $ 4972-4977      GDSTAT4 $ 4978-4982      GDSTAT5 $ 4983-4987   
   GDSTAT6 $ 4988-4992      GDSTAT7 $ 4993-4997      GDSTAT8 $ 4998-5002   
   GDSTAT9 $ 5003-5007      GDSTAT10 $ 5008-5012     GDSTAT11 $ 5013-5017  
   GDSTAT12 $ 5018-5022     GDSTAT13 $ 5023-5027     GDSTAT14 $ 5028-5032  
   GDSTAT15 $ 5033-5037     GDSTAT16 $ 5038-5042     GDSTAT17 $ 5043-5047  
   GDSTAT18 $ 5048-5052     GDSTAT19 $ 5053-5057     GDSTAT20 $ 5058-5062  
   GDSTAT21 $ 5063-5067     GDSTAT22 $ 5068-5072     GDSTAT23 $ 5073-5077  
   GDSTAT24 $ 5078-5082     GDSTAT25 $ 5083-5087     GDSTAT26 $ 5088-5092  
   GDSTAT27 $ 5093-5097     LOSS1  5098-5107         LOSS2  5108-5117      
   LOSS3  5118-5127         LOSS4  5128-5137         LOSS5  5138-5147      
   LOSS6  5148-5157         LOSS7  5158-5167         LOSS8  5168-5177      
   LOSS9  5178-5187         LOSS10  5188-5197        LOSS11  5198-5207     
   LOSS12  5208-5213        LOSS13  5214-5223        LOSS14  5224-5233     
   LOSS15  5234-5238        LOSS16  5239             LOSS17  5240          
   LOSS18  5241             LOSS19  5242             LOSS20  5243          
   LOSS21  5244             LOSS22  5245             LOSS23  5246          
   LOSS24  5247             LOSS25  5248             LOSS26  5249          
   LOSS27  5250             GDREF1 $ 5251-5256       GDREF2 $ 5257-5262    
   GDREF3 $ 5263-5267       GDREF4 $ 5268-5272       GDREF5 $ 5273-5277    
   GDREF6 $ 5278-5282       GDREF7 $ 5283-5287       GDREF8 $ 5288-5292    
   GDREF9 $ 5293-5297       GDREF10 $ 5298-5302      GDREF11 $ 5303-5307   
   GDREF12 $ 5308-5312      GDREF13 $ 5313-5317      GDREF14 $ 5318-5322   
   GDREF15 $ 5323-5327      GDREF16 $ 5328-5332      GDREF17 $ 5333-5337   
   GDREF18 $ 5338-5342      GDREF19 $ 5343-5347      GDREF20 $ 5348-5352   
   GDREF21 $ 5353-5357      GDREF22 $ 5358-5362      GDREF23 $ 5363-5367   
   GDREF24 $ 5368           GDREF25 $ 5369-5373      GDREF26 $ 5374        
   GDREF27 $ 5375-5379      LOSSR1  5380-5389        LOSSR2  5390-5399     
   LOSSR3  5400-5409        LOSSR4  5410-5419        LOSSR5  5420-5429     
   LOSSR6  5430-5439        LOSSR7  5440             LOSSR8  5441-5446     
   LOSSR9  5447             LOSSR10  5448            LOSSR11  5449         
   LOSSR12  5450            LOSSR13  5451            LOSSR14  5452         
   LOSSR15  5453            LOSSR16  5454            LOSSR17  5455         
   LOSSR18  5456            LOSSR19  5457            LOSSR20  5458         
   LOSSR21  5459            LOSSR22  5460            LOSSR23  5461         
   LOSSR24  5462            LOSSR25  5463            LOSSR26  5464         
   LOSSR27  5465            GDLINEHI $ 5466-5471     GDSTATHI $ 5472-5477  
   LOSSHI  5478-5487        GDREFHI $ 5488-5493      LOSSRHI  5494-5503    
   STA1_1 $ 5504-5516       STA1_2 $ 5517-5528       STA1_3 $ 5529-5540    
   STA1_4 $ 5541-5552       STA1_5 $ 5553-5564       STA1_6 $ 5565-5576    
   STA1_7 $ 5577-5587       STA1_8 $ 5588-5598       STA1_9 $ 5599-5611    
   STA1_10 $ 5612-5622      STA1_11 $ 5623-5633      STA1_12 $ 5634-5644   
   STA1_13 $ 5645-5655      STA1_14 $ 5656-5666      STA1_15 $ 5667-5677   
   STA1_16 $ 5678-5688      STA1_17 $ 5689-5699      STA1_18 $ 5700-5710   
   STA1_19 $ 5711-5721      STA1_20 $ 5722-5732      STA1_21 $ 5733-5743   
   STA1_22 $ 5744-5753      STA1_23 $ 5754-5763      STA1_24 $ 5764-5773   
   STA1_25 $ 5774-5783      STA1_26 $ 5784-5793      STA1_27 $ 5794-5803   
   STA1_28 $ 5804-5813      STA1_29 $ 5814-5824      STA1_30 $ 5825-5835   
   STA1_31 $ 5836-5845      STA1_32 $ 5846-5855      STA1_33 $ 5856-5865   
   STA1_34 $ 5866-5875      STA1_35 $ 5876-5885      STA1_36 $ 5886-5895   
   STA1_37 $ 5896-5905      STA1_38 $ 5906-5915      STA1_39 $ 5916-5925   
   STA1_40 $ 5926-5935      STA1_41 $ 5936-5945      STA1_42 $ 5946-5955   
   STA1_43 $ 5956-5965      STA1_44 $ 5966-5975      STA1_45 $ 5976-5985   
   STA1_46 $ 5986-5995      STA1_47 $ 5996-6005      STA1_48 $ 6006-6015   
   STA1_49 $ 6016-6025      STA1_50 $ 6026-6035      STA1_51 $ 6036-6045   
   STA1_52 $ 6046-6055      STA1_53 $ 6056-6065      STA1_54 $ 6066-6075   
   STA1_55 $ 6076-6085      STA1_56 $ 6086-6095      STA1_57 $ 6096-6105   
   STA1_58 $ 6106-6115      STA1_59 $ 6116-6125      STA1_60 $ 6126-6135   
   STA1_61 $ 6136-6145      STA1_62 $ 6146-6155      STA1_63 $ 6156-6165   
   STA1_64 $ 6166-6175      STA1_65 $ 6176-6185      STA1_66 $ 6186-6195   
   STA1_67 $ 6196-6205      STA1_68 $ 6206-6215      STA1_69 $ 6216-6225   
   STA1_70 $ 6226-6235      STA1_71 $ 6236-6245      STA1_72 $ 6246-6255   
   STA1_73 $ 6256-6265      STA1_74 $ 6266-6275      STA1_75 $ 6276-6285   
   STA1_76 $ 6286-6295      STA1_77 $ 6296-6305      STA1_78 $ 6306-6315   
   STA1_79 $ 6316-6325      STA1_80 $ 6326-6335      STA1_81 $ 6336-6345   
   STA1_82 $ 6346-6355      STA1_83 $ 6356-6365      STA1_84 $ 6366-6375   
   STA1_85 $ 6376-6385      STA1_86 $ 6386-6395      STA1_87 $ 6396-6405   
   STA1_88 $ 6406-6415      STA1_89 $ 6416-6425      STA1_90 $ 6426-6435   
   STA1_91 $ 6436-6445      STA1_92 $ 6446-6455      STA1_93 $ 6456-6465   
   STA1_94 $ 6466-6473      STA1_95 $ 6474-6483      STA1_96 $ 6484-6493   
   STA1_97 $ 6494-6503      STA1_98 $ 6504-6513      STA1_99 $ 6514-6523   
   STA1_100 $ 6524-6531     STA1_101 $ 6532-6541     STA1_102 $ 6542-6551  
   STA1_103 $ 6552-6561     STA1_104 $ 6562-6571     STA1_105 $ 6572-6581  
   STA1_106 $ 6582-6591     STA1_107 $ 6592-6601     STA1_108 $ 6602-6611  
   STA1_109 $ 6612-6621     STA1_110 $ 6622-6631     STA1_111 $ 6632-6638  
   STA1_112 $ 6639-6645     STA1_113 $ 6646-6652     STA1_114 $ 6653-6659  
   STA1_115 $ 6660-6666     STA1_116 $ 6667-6673     STA1_117 $ 6674-6680  
   STA1_118 $ 6681-6687     STA1_119 $ 6688-6694     STA1_120 $ 6695-6701  
   STA1_121 $ 6702-6708     STA1_122 $ 6709-6715     STA1_123 $ 6716-6722  
   STA1_124 $ 6723-6729     STA1_125 $ 6730-6736     STA1_126 $ 6737-6743  
   STA1_127 $ 6744-6750     STA1_128 $ 6751-6757     STA1_129 $ 6758-6764  
   STA1_130 $ 6765-6771     STA1_131 $ 6772-6779     STA1_132 $ 6780-6787  
   STA1_133 $ 6788-6795     STA1_134 $ 6796-6803     STA1_135 $ 6804-6810  
   STA1_136 $ 6811-6817     STA1_137 $ 6818-6824     STA1_138 $ 6825-6831  
   STA1_139 $ 6832-6838     STA1_140 $ 6839-6845     STA1_141 $ 6846-6852  
   STA1_142 $ 6853-6859     STA1_143 $ 6860-6866     STA1_144 $ 6867-6873  
   STA1_145 $ 6874-6880     STA1_146 $ 6881-6887     STA1_147 $ 6888-6894  
   STA1_148 $ 6895-6901     STA1_149 $ 6902-6908     STA1_150 $ 6909-6915  
   STA1_151 $ 6916-6922     STA1_152 $ 6923-6929     STA1_153 $ 6930-6936  
   STA1_154 $ 6937-6943     STA1_155 $ 6944-6950     STA1_156 $ 6951-6957  
   STA1_157 $ 6958-6964     STA1_158 $ 6965-6971     STA1_159 $ 6972-6978  
   STA1_160 $ 6979-6985     STA1_161 $ 6986-6992     STA1_162 $ 6993-6999  
   STA1_163 $ 7000-7006     STA1_164 $ 7007-7013     STA1_165 $ 7014-7020  
   STA1_166 $ 7021-7027     STA1_167 $ 7028-7034     STA1_168 $ 7035-7041  
   STA1_169 $ 7042-7048     STA1_170 $ 7049-7055     STA1_171 $ 7056-7062  
   STA1_172 $ 7063-7069     STA1_173 $ 7070-7076     STA1_174 $ 7077-7083  
   STA1_175 $ 7084-7090     STA1_176 $ 7091-7097     STA1_177 $ 7098-7104  
   STA1_178 $ 7105-7111     STA1_179 $ 7112-7118     STA1_180 $ 7119-7125  
   STA1_181 $ 7126-7132     STA1_182 $ 7133-7139     STA1_183 $ 7140-7146  
   STA1_184 $ 7147-7153     STA1_185 $ 7154-7160     STA1_186 $ 7161-7167  
   STA1_187 $ 7168-7174     STA1_188 $ 7175-7181     STA1_189 $ 7182-7188  
   STA1_190 $ 7189-7195     STA1_191 $ 7196-7202     STA1_192 $ 7203-7209  
   STA1_193 $ 7210-7216     STA1_194 $ 7217-7223     STA1_195 $ 7224-7230  
   STA1_196 $ 7231-7237     STA1_197 $ 7238-7244     STA1_198 $ 7245-7251  
   STA1_199 $ 7252-7258     STA1_200 $ 7259-7265     STA1_201 $ 7266-7272  
   STA1_202 $ 7273-7279     STA1_203 $ 7280-7286     STA1_204 $ 7287-7293  
   STA1_205 $ 7294-7300     STA1_206 $ 7301-7307     STA1_207 $ 7308-7314  
   STA1_208 $ 7315-7321     STA1_209 $ 7322-7328     STA1_210 $ 7329-7335  
   STA1_211 $ 7336-7342     STA1_212 $ 7343-7349     STA1_213 $ 7350-7356  
   STA1_214 $ 7357-7363     STA1_215 $ 7364-7370     STA1_216 $ 7371-7377  
   STA1_217 $ 7378-7384     STA1_218 $ 7385-7391     STA1_219 $ 7392-7398  
   STA1_220 $ 7399-7405     STA1_221 $ 7406-7412     STA1_222 $ 7413-7419  
   STA1_223 $ 7420-7426     STA1_224 $ 7427-7433     STA1_225 $ 7434-7440  
   STA1_226 $ 7441-7447     STA1_227 $ 7448-7454     STA1_228 $ 7455-7461  
   STA1_229 $ 7462-7468     STA1_230 $ 7469-7475     STA1_231 $ 7476-7482  
   STA1_232 $ 7483-7489     STA1_233 $ 7490-7496     STA1_234 $ 7497-7503  
   STA1_235 $ 7504-7510     STA1_236 $ 7511-7517     STA1_237 $ 7518-7524  
   STA1_238 $ 7525-7531     STA1_239 $ 7532-7538     STA1_240 $ 7539-7545  
   STA1_241 $ 7546-7552     STA1_242 $ 7553-7559     STA1_243 $ 7560-7566  
   STA1_244 $ 7567-7573     STA1_245 $ 7574-7580     STA1_246 $ 7581-7587  
   STA1_247 $ 7588-7594     STA1_248 $ 7595-7601     STA1_249 $ 7602-7608  
   STA1_250 $ 7609-7615     STA1_251 $ 7616-7622     STA1_252 $ 7623-7629  
   STA1_253 $ 7630-7636     STA1_254 $ 7637-7643     STA1_255 $ 7644-7650  
   STA1_256 $ 7651-7657     STA1_257 $ 7658-7664     STA1_258 $ 7665-7671  
   STA1_259 $ 7672-7678     STA1_260 $ 7679-7685     STA1_261 $ 7686-7692  
   STA1_262 $ 7693-7699     STA1_263 $ 7700-7706     STA1_264 $ 7707-7713  
   STA1_265 $ 7714-7720     STA1_266 $ 7721-7727     STA2_1 $ 7728-7740    
   STA2_2 $ 7741-7753       STA2_3 $ 7754-7766       STA2_4 $ 7767-7779    
   STA2_5 $ 7780-7792       STA2_6 $ 7793-7805       STA2_7 $ 7806-7818    
   STA2_8 $ 7819-7831       STA2_9 $ 7832-7842       STA2_10 $ 7843-7855   
   STA2_11 $ 7856-7866      STA2_12 $ 7867-7877      STA2_13 $ 7878-7887   
   STA2_14 $ 7888-7897      STA2_15 $ 7898-7908      STA2_16 $ 7909-7919   
   STA2_17 $ 7920-7930      STA2_18 $ 7931-7941      STA2_19 $ 7942-7952   
   STA2_20 $ 7953-7963      STA2_21 $ 7964-7974      STA2_22 $ 7975-7985   
   STA2_23 $ 7986-7996      STA2_24 $ 7997-8007      STA2_25 $ 8008-8018   
   STA2_26 $ 8019-8029      STA2_27 $ 8030-8040      STA2_28 $ 8041-8051   
   STA2_29 $ 8052-8061      STA2_30 $ 8062-8071      STA2_31 $ 8072-8081   
   STA2_32 $ 8082-8091      STA2_33 $ 8092-8101      STA2_34 $ 8102-8111   
   STA2_35 $ 8112-8121      STA2_36 $ 8122-8131      STA2_37 $ 8132-8140   
   STA2_38 $ 8141-8148      STA2_39 $ 8149-8157      STA2_40 $ 8158-8166   
   STA2_41 $ 8167-8176      STA2_42 $ 8177-8186      STA2_43 $ 8187-8196   
   STA2_44 $ 8197-8206      STA2_45 $ 8207-8216      STA2_46 $ 8217-8226   
   STA2_47 $ 8227-8236      STA2_48 $ 8237-8246      STA2_49 $ 8247-8256   
   STA2_50 $ 8257-8266      STA2_51 $ 8267-8276      STA2_52 $ 8277-8286   
   STA2_53 $ 8287-8296      STA2_54 $ 8297-8306      STA2_55 $ 8307-8316   
   STA2_56 $ 8317-8326      STA2_57 $ 8327-8334      STA2_58 $ 8335-8342   
   STA2_59 $ 8343-8350      STA2_60 $ 8351-8358      STA2_61 $ 8359-8366   
   STA2_62 $ 8367-8374      STA2_63 $ 8375-8382      STA2_64 $ 8383-8390   
   STA2_65 $ 8391-8398      STA2_66 $ 8399-8406      STA2_67 $ 8407-8414   
   STA2_68 $ 8415-8422      STA2_69 $ 8423-8430      STA2_70 $ 8431-8438   
   STA2_71 $ 8439-8446      STA2_72 $ 8447-8454      STA2_73 $ 8455-8462   
   STA2_74 $ 8463-8470      STA2_75 $ 8471-8478      STA2_76 $ 8479-8488   
   STA2_77 $ 8489-8498      STA2_78 $ 8499-8508      STA2_79 $ 8509-8518   
   STA2_80 $ 8519-8528      STA2_81 $ 8529-8538      STA2_82 $ 8539-8548   
   STA2_83 $ 8549-8558      STA2_84 $ 8559-8568      STA2_85 $ 8569-8578   
   STA2_86 $ 8579-8588      STA2_87 $ 8589-8598      STA2_88 $ 8599-8608   
   STA2_89 $ 8609-8618      STA2_90 $ 8619-8628      STA2_91 $ 8629-8638   
   STA2_92 $ 8639-8648      STA2_93 $ 8649-8658      STA2_94 $ 8659-8666   
   STA2_95 $ 8667-8674      STA2_96 $ 8675-8682      STA2_97 $ 8683-8690   
   STA2_98 $ 8691-8698      STA2_99 $ 8699-8706      STA2_100 $ 8707-8714  
   STA2_101 $ 8715-8722     STA2_102 $ 8723-8730     STA2_103 $ 8731-8738  
   STA2_104 $ 8739-8746     STA2_105 $ 8747-8754     STA2_106 $ 8755-8762  
   STA2_107 $ 8763-8770     STA2_108 $ 8771-8778     STA2_109 $ 8779-8786  
   STA2_110 $ 8787-8794     STA2_111 $ 8795-8802     STA2_112 $ 8803-8810  
   STA2_113 $ 8811-8818     STA2_114 $ 8819-8826     STA2_115 $ 8827-8834  
   STA2_116 $ 8835-8842     STA2_117 $ 8843-8850     STA2_118 $ 8851-8858  
   STA2_119 $ 8859-8866     STA2_120 $ 8867-8874     STA2_121 $ 8875-8882  
   STA2_122 $ 8883-8890     STA2_123 $ 8891-8898     STA2_124 $ 8899-8906  
   STA2_125 $ 8907-8914     STA2_126 $ 8915-8922     STA2_127 $ 8923-8930  
   STA2_128 $ 8931-8938     STA2_129 $ 8939-8946     STA2_130 $ 8947-8954  
   STA2_131 $ 8955-8962     STA2_132 $ 8963-8970     STA2_133 $ 8971-8978  
   STA2_134 $ 8979-8986     STA2_135 $ 8987-8994     STA2_136 $ 8995-9002  
   STA2_137 $ 9003-9010     STA2_138 $ 9011-9018     STA2_139 $ 9019-9026  
   STA2_140 $ 9027-9034     STA2_141 $ 9035-9042     STA2_142 $ 9043-9050  
   STA2_143 $ 9051-9058     STA2_144 $ 9059-9066     STA2_145 $ 9067-9074  
   STA2_146 $ 9075-9082     STA2_147 $ 9083-9090     STA2_148 $ 9091-9098  
   STA2_149 $ 9099-9106     STA2_150 $ 9107-9114     STA2_151 $ 9115-9122  
   STA2_152 $ 9123-9130     STA2_153 $ 9131-9138     STA2_154 $ 9139-9146  
   STA2_155 $ 9147-9154     STA2_156 $ 9155-9162     STA2_157 $ 9163-9170  
   STA2_158 $ 9171-9178     STA2_159 $ 9179-9186     STA2_160 $ 9187-9194  
   STA2_161 $ 9195-9202     STA2_162 $ 9203-9210     STA2_163 $ 9211-9218  
   STA2_164 $ 9219-9226     STA2_165 $ 9227-9234     STA2_166 $ 9235-9242  
   STA2_167 $ 9243-9250     STA2_168 $ 9251-9258     STA2_169 $ 9259-9266  
   STA2_170 $ 9267-9274     STA2_171 $ 9275-9282     STA2_172 $ 9283-9290  
   STA2_173 $ 9291-9298     STA2_174 $ 9299-9306     STA2_175 $ 9307-9314  
   STA2_176 $ 9315-9322     STA2_177 $ 9323-9330     STA2_178 $ 9331-9338  
   STA2_179 $ 9339-9346     STA2_180 $ 9347-9354     STA2_181 $ 9355-9362  
   STA2_182 $ 9363-9370     STA2_183 $ 9371-9378     STA2_184 $ 9379-9386  
   STA2_185 $ 9387-9394     STA2_186 $ 9395-9402     STA2_187 $ 9403-9410  
   STA2_188 $ 9411-9418     STA2_189 $ 9419-9426     STA2_190 $ 9427-9434  
   STA2_191 $ 9435-9442     STA2_192 $ 9443-9450     STA2_193 $ 9451-9458  
   STA2_194 $ 9459-9466     STA2_195 $ 9467-9474     STA2_196 $ 9475-9482  
   STA2_197 $ 9483-9490     STA2_198 $ 9491-9498     STA2_199 $ 9499-9506  
   STA2_200 $ 9507-9514     STA2_201 $ 9515-9522     STA2_202 $ 9523-9530  
   STA2_203 $ 9531-9538     STA2_204 $ 9539-9546     STA2_205 $ 9547-9554  
   STA2_206 $ 9555-9562     STA2_207 $ 9563-9570     STA2_208 $ 9571-9578  
   STA2_209 $ 9579-9586     STA2_210 $ 9587-9594     STA2_211 $ 9595-9602  
   STA2_212 $ 9603-9610     STA2_213 $ 9611-9618     STA2_214 $ 9619-9626  
   STA2_215 $ 9627-9634     STA2_216 $ 9635-9642     STA2_217 $ 9643-9650  
   STA2_218 $ 9651-9658     STA2_219 $ 9659-9666     STA2_220 $ 9667-9674  
   STA2_221 $ 9675-9682     STA2_222 $ 9683-9690     STA2_223 $ 9691-9698  
   STA2_224 $ 9699-9706     STA2_225 $ 9707-9714     STA2_226 $ 9715-9722  
   STA2_227 $ 9723-9730     STA2_228 $ 9731-9738     STA2_229 $ 9739-9746  
   STA2_230 $ 9747-9754     STA2_231 $ 9755-9762     STA2_232 $ 9763-9770  
   STA2_233 $ 9771-9778     STA2_234 $ 9779-9786     STA2_235 $ 9787-9794  
   STA2_236 $ 9795-9802     STA2_237 $ 9803-9810     STA2_238 $ 9811-9818  
   STA2_239 $ 9819-9826     STA2_240 $ 9827-9834     STA2_241 $ 9835-9842  
   STA2_242 $ 9843-9850     STA2_243 $ 9851-9858     STA2_244 $ 9859-9866  
   STA2_245 $ 9867-9874     STA2_246 $ 9875-9882     STA2_247 $ 9883-9890  
   STA2_248 $ 9891-9898     STA2_249 $ 9899-9906     STA2_250 $ 9907-9914  
   STA2_251 $ 9915-9922     STA2_252 $ 9923-9930     STA2_253 $ 9931-9938  
   STA2_254 $ 9939-9946     STA2_255 $ 9947-9954     STA2_256 $ 9955-9962  
   STA2_257 $ 9963-9970     STA2_258 $ 9971-9978     STA2_259 $ 9979-9986  
   STA2_260 $ 9987-9994     STA2_261 $ 9995-10002    STA2_262 $ 10003-10010
   STA2_263 $ 10011-10018   STA2_264 $ 10019-10026   STA2_265 $ 10027-10034
   STA2_266 $ 10035-10042   STA3_1 $ 10043-10054     STA3_2 $ 10055-10066  
   STA3_3 $ 10067-10078     STA3_4 $ 10079-10090     STA3_5 $ 10091-10102  
   STA3_6 $ 10103-10114     STA3_7 $ 10115-10126     STA3_8 $ 10127-10138  
   STA3_9 $ 10139-10150     STA3_10 $ 10151-10162    STA3_11 $ 10163-10174 
   STA3_12 $ 10175-10185    STA3_13 $ 10186-10196    STA3_14 $ 10197-10207 
   STA3_15 $ 10208-10218    STA3_16 $ 10219-10229    STA3_17 $ 10230-10240 
   STA3_18 $ 10241-10251    STA3_19 $ 10252-10262    STA3_20 $ 10263-10273 
   STA3_21 $ 10274-10284    STA3_22 $ 10285-10295    STA3_23 $ 10296-10306 
   STA3_24 $ 10307-10317    STA3_25 $ 10318-10328    STA3_26 $ 10329-10339 
   STA3_27 $ 10340-10350    STA3_28 $ 10351-10361    STA3_29 $ 10362-10372 
   STA3_30 $ 10373-10383    STA3_31 $ 10384-10394    STA3_32 $ 10395-10405 
   STA3_33 $ 10406-10416    STA3_34 $ 10417-10427    STA3_35 $ 10428-10438 
   STA3_36 $ 10439-10444    STA3_37 $ 10445-10450    STA3_38 $ 10451-10456 
   STA3_39 $ 10457-10462    STA3_40 $ 10463-10468    STA3_41 $ 10469-10478 
   STA3_42 $ 10479-10488    STA3_43 $ 10489-10498    STA3_44 $ 10499-10508 
   STA3_45 $ 10509-10518    STA3_46 $ 10519-10528    STA3_47 $ 10529-10538 
   STA3_48 $ 10539-10548    STA3_49 $ 10549-10558    STA3_50 $ 10559-10568 
   STA3_51 $ 10569-10578    STA3_52 $ 10579-10588    STA3_53 $ 10589-10598 
   STA3_54 $ 10599-10608    STA3_55 $ 10609-10618    STA3_56 $ 10619-10628 
   STA3_57 $ 10629-10634    STA3_58 $ 10635-10640    STA3_59 $ 10641-10646 
   STA3_60 $ 10647-10652    STA3_61 $ 10653-10658    STA3_62 $ 10659-10664 
   STA3_63 $ 10665-10670    STA3_64 $ 10671-10676    STA3_65 $ 10677-10682 
   STA3_66 $ 10683-10688    STA3_67 $ 10689-10694    STA3_68 $ 10695-10700 
   STA3_69 $ 10701-10706    STA3_70 $ 10707-10712    STA3_71 $ 10713-10718 
   STA3_72 $ 10719-10724    STA3_73 $ 10725-10730    STA3_74 $ 10731-10736 
   STA3_75 $ 10737-10742    STA3_76 $ 10743-10748    STA3_77 $ 10749-10754 
   STA3_78 $ 10755-10760    STA3_79 $ 10761-10766    STA3_80 $ 10767-10772 
   STA3_81 $ 10773-10778    STA3_82 $ 10779-10784    STA3_83 $ 10785-10790 
   STA3_84 $ 10791-10796    STA3_85 $ 10797-10802    STA3_86 $ 10803-10808 
   STA3_87 $ 10809-10814    STA3_88 $ 10815-10820    STA3_89 $ 10821-10826 
   STA3_90 $ 10827-10832    STA3_91 $ 10833-10838    STA3_92 $ 10839-10844 
   STA3_93 $ 10845-10850    STA3_94 $ 10851-10856    STA3_95 $ 10857-10862 
   STA3_96 $ 10863-10868    STA3_97 $ 10869-10874    STA3_98 $ 10875-10880 
   STA3_99 $ 10881-10886    STA3_100 $ 10887-10892   STA3_101 $ 10893-10898
   STA3_102 $ 10899-10904   STA3_103 $ 10905-10910   STA3_104 $ 10911-10916
   STA3_105 $ 10917-10922   STA3_106 $ 10923-10928   STA3_107 $ 10929-10934
   STA3_108 $ 10935-10940   STA3_109 $ 10941-10946   STA3_110 $ 10947-10952
   STA3_111 $ 10953-10958   STA3_112 $ 10959-10964   STA3_113 $ 10965-10970
   STA3_114 $ 10971-10976   STA3_115 $ 10977-10982   STA3_116 $ 10983-10988
   STA3_117 $ 10989-10994   STA3_118 $ 10995-11000   STA3_119 $ 11001-11006
   STA3_120 $ 11007-11012   STA3_121 $ 11013-11018   STA3_122 $ 11019-11024
   STA3_123 $ 11025-11030   STA3_124 $ 11031-11036   STA3_125 $ 11037-11042
   STA3_126 $ 11043-11048   STA3_127 $ 11049-11054   STA3_128 $ 11055-11060
   STA3_129 $ 11061-11066   STA3_130 $ 11067-11072   STA3_131 $ 11073-11078
   STA3_132 $ 11079-11084   STA3_133 $ 11085-11090   STA3_134 $ 11091      
   STA3_135 $ 11092-11097   STA3_136 $ 11098-11103   STA3_137 $ 11104-11109
   STA3_138 $ 11110-11115   STA3_139 $ 11116-11121   STA3_140 $ 11122-11127
   STA3_141 $ 11128-11133   STA3_142 $ 11134-11139   STA3_143 $ 11140-11145
   STA3_144 $ 11146-11151   STA3_145 $ 11152-11157   STA3_146 $ 11158-11163
   STA3_147 $ 11164-11169   STA3_148 $ 11170-11175   STA3_149 $ 11176-11181
   STA3_150 $ 11182-11187   STA3_151 $ 11188-11193   STA3_152 $ 11194-11199
   STA3_153 $ 11200-11205   STA3_154 $ 11206-11211   STA3_155 $ 11212-11217
   STA3_156 $ 11218-11223   STA3_157 $ 11224-11229   STA3_158 $ 11230-11235
   STA3_159 $ 11236-11241   STA3_160 $ 11242-11247   STA3_161 $ 11248-11253
   STA3_162 $ 11254-11259   STA3_163 $ 11260-11265   STA3_164 $ 11266-11271
   STA3_165 $ 11272-11277   STA3_166 $ 11278-11283   STA3_167 $ 11284-11289
   STA3_168 $ 11290-11295   STA3_169 $ 11296-11301   STA3_170 $ 11302-11307
   STA3_171 $ 11308-11313   STA3_172 $ 11314-11319   STA3_173 $ 11320-11325
   STA3_174 $ 11326-11331   STA3_175 $ 11332-11337   STA3_176 $ 11338-11343
   STA3_177 $ 11344-11349   STA3_178 $ 11350-11355   STA3_179 $ 11356-11361
   STA3_180 $ 11362-11367   STA3_181 $ 11368-11373   STA3_182 $ 11374-11379
   STA3_183 $ 11380-11385   STA3_184 $ 11386-11391   STA3_185 $ 11392-11397
   STA3_186 $ 11398-11403   STA3_187 $ 11404-11409   STA3_188 $ 11410-11415
   STA3_189 $ 11416-11421   STA3_190 $ 11422-11427   STA3_191 $ 11428-11433
   STA3_192 $ 11434-11439   STA3_193 $ 11440-11445   STA3_194 $ 11446-11451
   STA3_195 $ 11452-11457   STA3_196 $ 11458-11463   STA3_197 $ 11464-11469
   STA3_198 $ 11470-11475   STA3_199 $ 11476-11481   STA3_200 $ 11482-11487
   STA3_201 $ 11488-11493   STA3_202 $ 11494-11499   STA3_203 $ 11500-11505
   STA3_204 $ 11506-11511   STA3_205 $ 11512-11517   STA3_206 $ 11518-11523
   STA3_207 $ 11524-11529   STA3_208 $ 11530-11535   STA3_209 $ 11536-11541
   STA3_210 $ 11542-11547   STA3_211 $ 11548-11553   STA3_212 $ 11554-11559
   STA3_213 $ 11560-11565   STA3_214 $ 11566-11571   STA3_215 $ 11572-11577
   STA3_216 $ 11578-11583   STA3_217 $ 11584-11589   STA3_218 $ 11590-11595
   STA3_219 $ 11596-11601   STA3_220 $ 11602-11607   STA3_221 $ 11608-11613
   STA3_222 $ 11614-11619   STA3_223 $ 11620-11625   STA3_224 $ 11626-11631
   STA3_225 $ 11632-11637   STA3_226 $ 11638-11643   STA3_227 $ 11644-11649
   STA3_228 $ 11650-11655   STA3_229 $ 11656-11661   STA3_230 $ 11662-11667
   STA3_231 $ 11668-11673   STA3_232 $ 11674-11679   STA3_233 $ 11680-11685
   STA3_234 $ 11686-11691   STA3_235 $ 11692-11697   STA3_236 $ 11698-11703
   STA3_237 $ 11704-11709   STA3_238 $ 11710-11715   STA3_239 $ 11716-11721
   STA3_240 $ 11722-11727   STA3_241 $ 11728-11733   STA3_242 $ 11734-11739
   STA3_243 $ 11740-11745   STA3_244 $ 11746-11751   STA3_245 $ 11752-11757
   STA3_246 $ 11758-11763   STA3_247 $ 11764-11769   STA3_248 $ 11770-11775
   STA3_249 $ 11776-11781   STA3_250 $ 11782-11787   STA3_251 $ 11788-11793
   STA3_252 $ 11794-11799   STA3_253 $ 11800-11805   STA3_254 $ 11806-11811
   STA3_255 $ 11812-11817   STA3_256 $ 11818-11823   STA3_257 $ 11824-11829
   STA3_258 $ 11830-11835   STA3_259 $ 11836-11841   STA3_260 $ 11842-11847
   STA3_261 $ 11848-11853   STA3_262 $ 11854-11859   STA3_263 $ 11860-11865
   STA3_264 $ 11866-11871   STA3_265 $ 11872-11877   STA3_266 $ 11878-11883
   NWSTAT1 $ 11884-11896    NWSTAT2 $ 11897-11909    NWSTAT3 $ 11910-11921 
   NWSTAT4 $ 11922-11933    NWSTAT5 $ 11934-11945    NWSTAT6 $ 11946-11957 
   NWSTAT7 $ 11958-11969    NWSTAT8 $ 11970-11981    NWSTAT9 $ 11982-11993 
   NWSTAT10 $ 11994-12005   NWSTAT11 $ 12006-12014   NWSTAT12 $ 12015-12025
   NWSTAT13 $ 12026-12035   NWSTAT14 $ 12036-12043   NWSTAT15 $ 12044-12051
   NWSTAT16 $ 12052-12059   NWSTAT17 $ 12060-12069   OFBEG1 DATE11.        
   OFBEG2 DATE11.           OFBEG3 DATE11.           OFBEG4 DATE11.        
   OFBEG5 DATE11.           OFBEG6 DATE11.           OFBEG7 DATE11.        
   OFBEG8 DATE11.           OFBEG9 DATE11.           OFBEG10 DATE11.       
   OFBEG11 DATE11.          OFBEG12 DATE11.          OFBEG13 DATE11.       
   OFBEG14 DATE11.          OFBEG15 DATE11.          OFBEG16 DATE11.       
   OFBEG17 DATE11.          OFBEG18 DATE11.          OFBEG19 DATE11.       
   OFBEG20 DATE11.          OFBEG21 DATE11.          OFBEG22 DATE11.       
   OFBEG23 DATE11.          OFBEG24 DATE11.          OFBEG25 DATE11.       
   OFBEG26 DATE11.          OFBEG27 DATE11.          OFBEG28 DATE11.       
   OFBEG29 DATE11.          OFBEG30 DATE11.          OFBEG31 DATE11.       
   OFBEG32 DATE11.          OFBEG33 DATE11.          OFBEG34 DATE11.       
   OFBEG35 DATE11.          OFBEG36 DATE11.          OFBEG37 DATE11.       
   OFBEG38 DATE11.          OFBEG39 DATE11.          OFBEG40 DATE11.       
   OFBEG41 DATE11.          OFBEG42 DATE11.          OFBEG43 DATE11.       
   OFBEG44 DATE11.          OFBEG45 DATE11.          OFBEG46 DATE11.       
   OFBEG47 DATE11.          OFBEG48 DATE11.          OFBEG49 DATE11.       
   OFBEG50 DATE11.          OFBEG51 DATE11.          OFBEG52 DATE11.       
   OFBEG53 DATE11.          OFBEG54 DATE11.          OFBEG55 DATE11.       
   OFBEG56 DATE11.          OFBEG57 DATE11.          OFBEG58 DATE11.       
   OFBEG59 DATE11.          OFBEG60 DATE11.          OFBEG61 DATE11.       
   OFBEG62 DATE11.          OFBEG63 DATE11.          OFBEG64 DATE11.       
   OFBEG65 DATE11.          OFBEG66 DATE11.          OFBEG67 DATE11.       
   OFBEG68 DATE11.          OFBEG69 DATE11.          OFBEG70 DATE11.       
   OFBEG71 DATE11.          OFBEG72 DATE11.          OFBEG73 DATE11.       
   OFBEG74 DATE11.          OFBEG75 DATE11.          OFBEG76 DATE11.       
   OFBEG77 DATE11.          OFBEG78 DATE11.          OFBEG79 DATE11.       
   OFBEG80 DATE11.          OFBEG81 DATE11.          OFBEG82 DATE11.       
   OFBEG83 DATE11.          OFBEG84 DATE11.          OFBEG85 DATE11.       
   OFBEG86 DATE11.          OFBEG87 DATE11.          OFBEG88 DATE11.       
   OFBEG89 DATE11.          OFBEG90 DATE11.          OFBEG91 DATE11.       
   OFBEG92 DATE11.          OFBEG93 DATE11.          OFBEG94 DATE11.       
   OFBEG95 DATE11.          OFBEG96 DATE11.          OFBEG97 DATE11.       
   OFBEG98 DATE11.          OFBEG99 DATE11.          OFBEG100 DATE11.      
   OFBEG101 DATE11.         OFBEG102 DATE11.         OFBEG103 DATE11.      
   OFBEG104 DATE11.         OFBEG105 DATE11.         OFBEG106 DATE11.      
   OFBEG107 DATE11.         OFBEG108 DATE11.         OFBEG109 DATE11.      
   OFBEG110 DATE11.         OFBEG111 DATE11.         OFBEG112 DATE11.      
   OFBEG113 DATE11.         OFBEG114 DATE11.         OFBEG115 DATE11.      
   OFBEG116 DATE11.         OFBEG117 DATE11.         OFBEG118 DATE11.      
   OFBEG119 DATE11.         OFBEG120 DATE11.         OFBEG121 DATE11.      
   OFBEG122 DATE11.         OFBEG123 DATE11.         OFBEG124 DATE11.      
   OFBEG125 DATE11.         OFBEG126 DATE11.         OFBEG127 DATE11.      
   OFBEG128 DATE11.         OFBEG129 DATE11.         OFBEG130 DATE11.      
   OFBEG131 DATE11.         OFBEG132 DATE11.         OFBEG133 DATE11.      
   OFBEG134 DATE11.         OFBEG135 DATE11.         OFBEG136 DATE11.      
   OFBEG137 DATE11.         OFBEG138 DATE11.         OFBEG139 DATE11.      
   OFBEG140 DATE11.         OFBEG141 DATE11.         OFBEG142 DATE11.      
   OFBEG143 DATE11.         OFBEG144 DATE11.         OFBEG145 DATE11.      
   OFBEG146 DATE11.         OFBEG147 DATE11.         OFBEG148 DATE11.      
   OFBEG149 DATE11.         OFBEG150 DATE11.         OFBEG151 DATE11.      
   OFBEG152 DATE11.         OFBEG153 DATE11.         OFBEG154 DATE11.      
   OFBEG155 DATE11.         OFBEG156 DATE11.         OFBEG157 DATE11.      
   OFBEG158 DATE11.         OFBEG159 DATE11.         OFBEG160 DATE11.      
   OFBEG161 DATE11.         OFBEG162 DATE11.         OFBEG163 DATE11.      
   OFBEG164 DATE11.         OFBEG165 DATE11.         OFBEG166 DATE11.      
   OFBEG167 DATE11.         OFBEG168 DATE11.         OFBEG169 DATE11.      
   OFBEG170 DATE11.         OFBEG171 DATE11.         OFBEG172 DATE11.      
   OFBEG173 DATE11.         OFBEG174 DATE11.         OFBEG175 DATE11.      
   OFBEG176 DATE11.         OFBEG177 DATE11.         OFBEG178 DATE11.      
   OFBEG179 DATE11.         OFBEG180 DATE11.         OFBEG181 DATE11.      
   OFBEG182 DATE11.         OFBEG183 DATE11.         OFBEG184 DATE11.      
   OFBEG185 DATE11.         OFBEG186 DATE11.         OFBEG187 DATE11.      
   OFBEG188 DATE11.         OFBEG189 DATE11.         OFBEG190 DATE11.      
   OFBEG191 DATE11.         OFBEG192 DATE11.         OFBEG193 DATE11.      
   OFBEG194 DATE11.         OFBEG195 DATE11.         OFBEG196 DATE11.      
   OFBEG197 DATE11.         OFBEG198 DATE11.         OFBEG199 DATE11.      
   OFBEG200 DATE11.         OFBEG201 DATE11.         OFBEG202 DATE11.      
   OFBEG203 DATE11.         OFBEG204 DATE11.         OFBEG205 DATE11.      
   OFBEG206 DATE11.         OFBEG207 DATE11.         OFBEG208 DATE11.      
   OFBEG209 DATE11.         OFBEG210 DATE11.         OFBEG211 DATE11.      
   OFBEG212 DATE11.         OFBEG213 DATE11.         OFBEG214 DATE11.      
   OFBEG215 DATE11.         OFBEG216 DATE11.         OFBEG217 DATE11.      
   OFBEG218 DATE11.         OFBEG219 DATE11.         OFBEG220 DATE11.      
   OFBEG221 DATE11.         OFBEG222 DATE11.         OFBEG223 DATE11.      
   OFBEG224 DATE11.         OFBEG225 DATE11.         OFBEG226 DATE11.      
   OFBEG227 DATE11.         OFBEG228 DATE11.         OFBEG229 DATE11.      
   OFBEG230 DATE11.         OFBEG231 DATE11.         OFBEG232 DATE11.      
   OFBEG233 DATE11.         OFBEG234 DATE11.         OFBEG235 DATE11.      
   OFBEG236 DATE11.         OFBEG237 DATE11.         OFBEG238 DATE11.      
   OFBEG239 DATE11.         OFBEG240 DATE11.         OFBEG241 DATE11.      
   OFBEG242 DATE11.         OFBEG243 DATE11.         OFBEG244 DATE11.      
   OFBEG245 DATE11.         OFBEG246 DATE11.         OFBEG247 DATE11.      
   OFBEG248 DATE11.         OFBEG249 DATE11.         OFBEG250 DATE11.      
   OFBEG251 DATE11.         OFBEG252 DATE11.         OFBEG253 DATE11.      
   OFBEG254 DATE11.         OFBEG255 DATE11.         OFBEG256 DATE11.      
   OFBEG257 DATE11.         OFBEG258 DATE11.         OFBEG259 DATE11.      
   OFBEG260 DATE11.         OFBEG261 DATE11.         OFBEG262 DATE11.      
   OFBEG263 DATE11.         OFBEG264 DATE11.         OFBEG265 DATE11.      
   OFBEG266 DATE11.         OFEND1 DATE11.           OFEND2 DATE11.        
   OFEND3 DATE11.           OFEND4 DATE11.           OFEND5 DATE11.        
   OFEND6 DATE11.           OFEND7 DATE11.           OFEND8 DATE11.        
   OFEND9 DATE11.           OFEND10 DATE11.          OFEND11 DATE11.       
   OFEND12 DATE11.          OFEND13 DATE11.          OFEND14 DATE11.       
   OFEND15 DATE11.          OFEND16 DATE11.          OFEND17 DATE11.       
   OFEND18 DATE11.          OFEND19 DATE11.          OFEND20 DATE11.       
   OFEND21 DATE11.          OFEND22 DATE11.          OFEND23 DATE11.       
   OFEND24 DATE11.          OFEND25 DATE11.          OFEND26 DATE11.       
   OFEND27 DATE11.          OFEND28 DATE11.          OFEND29 DATE11.       
   OFEND30 DATE11.          OFEND31 DATE11.          OFEND32 DATE11.       
   OFEND33 DATE11.          OFEND34 DATE11.          OFEND35 DATE11.       
   OFEND36 DATE11.          OFEND37 DATE11.          OFEND38 DATE11.       
   OFEND39 DATE11.          OFEND40 DATE11.          OFEND41 DATE11.       
   OFEND42 DATE11.          OFEND43 DATE11.          OFEND44 DATE11.       
   OFEND45 DATE11.          OFEND46 DATE11.          OFEND47 DATE11.       
   OFEND48 DATE11.          OFEND49 DATE11.          OFEND50 DATE11.       
   OFEND51 DATE11.          OFEND52 DATE11.          OFEND53 DATE11.       
   OFEND54 DATE11.          OFEND55 DATE11.          OFEND56 DATE11.       
   OFEND57 DATE11.          OFEND58 DATE11.          OFEND59 DATE11.       
   OFEND60 DATE11.          OFEND61 DATE11.          OFEND62 DATE11.       
   OFEND63 DATE11.          OFEND64 DATE11.          OFEND65 DATE11.       
   OFEND66 DATE11.          OFEND67 DATE11.          OFEND68 DATE11.       
   OFEND69 DATE11.          OFEND70 DATE11.          OFEND71 DATE11.       
   OFEND72 DATE11.          OFEND73 DATE11.          OFEND74 DATE11.       
   OFEND75 DATE11.          OFEND76 DATE11.          OFEND77 DATE11.       
   OFEND78 DATE11.          OFEND79 DATE11.          OFEND80 DATE11.       
   OFEND81 DATE11.          OFEND82 DATE11.          OFEND83 DATE11.       
   OFEND84 DATE11.          OFEND85 DATE11.          OFEND86 DATE11.       
   OFEND87 DATE11.          OFEND88 DATE11.          OFEND89 DATE11.       
   OFEND90 DATE11.          OFEND91 DATE11.          OFEND92 DATE11.       
   OFEND93 DATE11.          OFEND94 DATE11.          OFEND95 DATE11.       
   OFEND96 DATE11.          OFEND97 DATE11.          OFEND98 DATE11.       
   OFEND99 DATE11.          OFEND100 DATE11.         OFEND101 DATE11.      
   OFEND102 DATE11.         OFEND103 DATE11.         OFEND104 DATE11.      
   OFEND105 DATE11.         OFEND106 DATE11.         OFEND107 DATE11.      
   OFEND108 DATE11.         OFEND109 DATE11.         OFEND110 DATE11.      
   OFEND111 DATE11.         OFEND112 DATE11.         OFEND113 DATE11.      
   OFEND114 DATE11.         OFEND115 DATE11.         OFEND116 DATE11.      
   OFEND117 DATE11.         OFEND118 DATE11.         OFEND119 DATE11.      
   OFEND120 DATE11.         OFEND121 DATE11.         OFEND122 DATE11.      
   OFEND123 DATE11.         OFEND124 DATE11.         OFEND125 DATE11.      
   OFEND126 DATE11.         OFEND127 DATE11.         OFEND128 DATE11.      
   OFEND129 DATE11.         OFEND130 DATE11.         OFEND131 DATE11.      
   OFEND132 DATE11.         OFEND133 DATE11.         OFEND134 DATE11.      
   OFEND135 DATE11.         OFEND136 DATE11.         OFEND137 DATE11.      
   OFEND138 DATE11.         OFEND139 DATE11.         OFEND140 DATE11.      
   OFEND141 DATE11.         OFEND142 DATE11.         OFEND143 DATE11.      
   OFEND144 DATE11.         OFEND145 DATE11.         OFEND146 DATE11.      
   OFEND147 DATE11.         OFEND148 DATE11.         OFEND149 DATE11.      
   OFEND150 DATE11.         OFEND151 DATE11.         OFEND152 DATE11.      
   OFEND153 DATE11.         OFEND154 DATE11.         OFEND155 DATE11.      
   OFEND156 DATE11.         OFEND157 DATE11.         OFEND158 DATE11.      
   OFEND159 DATE11.         OFEND160 DATE11.         OFEND161 DATE11.      
   OFEND162 DATE11.         OFEND163 DATE11.         OFEND164 DATE11.      
   OFEND165 DATE11.         OFEND166 DATE11.         OFEND167 DATE11.      
   OFEND168 DATE11.         OFEND169 DATE11.         OFEND170 DATE11.      
   OFEND171 DATE11.         OFEND172 DATE11.         OFEND173 DATE11.      
   OFEND174 DATE11.         OFEND175 DATE11.         OFEND176 DATE11.      
   OFEND177 DATE11.         OFEND178 DATE11.         OFEND179 DATE11.      
   OFEND180 DATE11.         OFEND181 DATE11.         OFEND182 DATE11.      
   OFEND183 DATE11.         OFEND184 DATE11.         OFEND185 DATE11.      
   OFEND186 DATE11.         OFEND187 DATE11.         OFEND188 DATE11.      
   OFEND189 DATE11.         OFEND190 DATE11.         OFEND191 DATE11.      
   OFEND192 DATE11.         OFEND193 DATE11.         OFEND194 DATE11.      
   OFEND195 DATE11.         OFEND196 DATE11.         OFEND197 DATE11.      
   OFEND198 DATE11.         OFEND199 DATE11.         OFEND200 DATE11.      
   OFEND201 DATE11.         OFEND202 DATE11.         OFEND203 DATE11.      
   OFEND204 DATE11.         OFEND205 DATE11.         OFEND206 DATE11.      
   OFEND207 DATE11.         OFEND208 DATE11.         OFEND209 DATE11.      
   OFEND210 DATE11.         OFEND211 DATE11.         OFEND212 DATE11.      
   OFEND213 DATE11.         OFEND214 DATE11.         OFEND215 DATE11.      
   OFEND216 DATE11.         OFEND217 DATE11.         OFEND218 DATE11.      
   OFEND219 DATE11.         OFEND220 DATE11.         OFEND221 DATE11.      
   OFEND222 DATE11.         OFEND223 DATE11.         OFEND224 DATE11.      
   OFEND225 DATE11.         OFEND226 DATE11.         OFEND227 DATE11.      
   OFEND228 DATE11.         OFEND229 DATE11.         OFEND230 DATE11.      
   OFEND231 DATE11.         OFEND232 DATE11.         OFEND233 DATE11.      
   OFEND234 DATE11.         OFEND235 DATE11.         OFEND236 DATE11.      
   OFEND237 DATE11.         OFEND238 DATE11.         OFEND239 DATE11.      
   OFEND240 DATE11.         OFEND241 DATE11.         OFEND242 DATE11.      
   OFEND243 DATE11.         OFEND244 DATE11.         OFEND245 DATE11.      
   OFEND246 DATE11.         OFEND247 DATE11.         OFEND248 DATE11.      
   OFEND249 DATE11.         OFEND250 DATE11.         OFEND251 DATE11.      
   OFEND252 DATE11.         OFEND253 DATE11.         OFEND254 DATE11.      
   OFEND255 DATE11.         OFEND256 DATE11.         OFEND257 DATE11.      
   OFEND258 DATE11.         OFEND259 DATE11.         OFEND260 DATE11.      
   OFEND261 DATE11.         OFEND262 DATE11.         OFEND263 DATE11.      
   OFEND264 DATE11.         OFEND265 DATE11.         OFEND266 DATE11.      
   CRPTS  17922             MWGT1  17923-17940       MWGT2  17941-17958    
   MWGT3  17959-17976       MWGT4  17977-17994       MWGT5  17995-17999    
   WGT1  18000-18019        WGT2  18020-18038        WGT3  18039-18056     
   WGT4  18057-18074        WGT5  18075-18079        DRGAM1  18080-18088   
   DRGAM2  18089-18097      DRGAM3  18098-18106      DRGAM4  18107-18114   
   DRGAM5  18115-18119      DATO1  18120-18126       DATO2  18127-18131    
   DATO3  18132-18135       DATO4  18136             DATO5  18137          
   DAFROM1  18138-18144     DAFROM2  18145-18149     DAFROM3  18150-18153  
   DAFROM4  18154           DAFROM5  18155           MWEIGHT  18156-18173  
 ;                       

FORMAT
   SENTDATE DATE9.          DOB DATE9.               OFBEG1 DATE9.         
   OFBEG2 DATE9.            OFBEG3 DATE9.            OFBEG4 DATE9.         
   OFBEG5 DATE9.            OFBEG6 DATE9.            OFBEG7 DATE9.         
   OFBEG8 DATE9.            OFBEG9 DATE9.            OFBEG10 DATE9.        
   OFBEG11 DATE9.           OFBEG12 DATE9.           OFBEG13 DATE9.        
   OFBEG14 DATE9.           OFBEG15 DATE9.           OFBEG16 DATE9.        
   OFBEG17 DATE9.           OFBEG18 DATE9.           OFBEG19 DATE9.        
   OFBEG20 DATE9.           OFBEG21 DATE9.           OFBEG22 DATE9.        
   OFBEG23 DATE9.           OFBEG24 DATE9.           OFBEG25 DATE9.        
   OFBEG26 DATE9.           OFBEG27 DATE9.           OFBEG28 DATE9.        
   OFBEG29 DATE9.           OFBEG30 DATE9.           OFBEG31 DATE9.        
   OFBEG32 DATE9.           OFBEG33 DATE9.           OFBEG34 DATE9.        
   OFBEG35 DATE9.           OFBEG36 DATE9.           OFBEG37 DATE9.        
   OFBEG38 DATE9.           OFBEG39 DATE9.           OFBEG40 DATE9.        
   OFBEG41 DATE9.           OFBEG42 DATE9.           OFBEG43 DATE9.        
   OFBEG44 DATE9.           OFBEG45 DATE9.           OFBEG46 DATE9.        
   OFBEG47 DATE9.           OFBEG48 DATE9.           OFBEG49 DATE9.        
   OFBEG50 DATE9.           OFBEG51 DATE9.           OFBEG52 DATE9.        
   OFBEG53 DATE9.           OFBEG54 DATE9.           OFBEG55 DATE9.        
   OFBEG56 DATE9.           OFBEG57 DATE9.           OFBEG58 DATE9.        
   OFBEG59 DATE9.           OFBEG60 DATE9.           OFBEG61 DATE9.        
   OFBEG62 DATE9.           OFBEG63 DATE9.           OFBEG64 DATE9.        
   OFBEG65 DATE9.           OFBEG66 DATE9.           OFBEG67 DATE9.        
   OFBEG68 DATE9.           OFBEG69 DATE9.           OFBEG70 DATE9.        
   OFBEG71 DATE9.           OFBEG72 DATE9.           OFBEG73 DATE9.        
   OFBEG74 DATE9.           OFBEG75 DATE9.           OFBEG76 DATE9.        
   OFBEG77 DATE9.           OFBEG78 DATE9.           OFBEG79 DATE9.        
   OFBEG80 DATE9.           OFBEG81 DATE9.           OFBEG82 DATE9.        
   OFBEG83 DATE9.           OFBEG84 DATE9.           OFBEG85 DATE9.        
   OFBEG86 DATE9.           OFBEG87 DATE9.           OFBEG88 DATE9.        
   OFBEG89 DATE9.           OFBEG90 DATE9.           OFBEG91 DATE9.        
   OFBEG92 DATE9.           OFBEG93 DATE9.           OFBEG94 DATE9.        
   OFBEG95 DATE9.           OFBEG96 DATE9.           OFBEG97 DATE9.        
   OFBEG98 DATE9.           OFBEG99 DATE9.           OFBEG100 DATE9.       
   OFBEG101 DATE9.          OFBEG102 DATE9.          OFBEG103 DATE9.       
   OFBEG104 DATE9.          OFBEG105 DATE9.          OFBEG106 DATE9.       
   OFBEG107 DATE9.          OFBEG108 DATE9.          OFBEG109 DATE9.       
   OFBEG110 DATE9.          OFBEG111 DATE9.          OFBEG112 DATE9.       
   OFBEG113 DATE9.          OFBEG114 DATE9.          OFBEG115 DATE9.       
   OFBEG116 DATE9.          OFBEG117 DATE9.          OFBEG118 DATE9.       
   OFBEG119 DATE9.          OFBEG120 DATE9.          OFBEG121 DATE9.       
   OFBEG122 DATE9.          OFBEG123 DATE9.          OFBEG124 DATE9.       
   OFBEG125 DATE9.          OFBEG126 DATE9.          OFBEG127 DATE9.       
   OFBEG128 DATE9.          OFBEG129 DATE9.          OFBEG130 DATE9.       
   OFBEG131 DATE9.          OFBEG132 DATE9.          OFBEG133 DATE9.       
   OFBEG134 DATE9.          OFBEG135 DATE9.          OFBEG136 DATE9.       
   OFBEG137 DATE9.          OFBEG138 DATE9.          OFBEG139 DATE9.       
   OFBEG140 DATE9.          OFBEG141 DATE9.          OFBEG142 DATE9.       
   OFBEG143 DATE9.          OFBEG144 DATE9.          OFBEG145 DATE9.       
   OFBEG146 DATE9.          OFBEG147 DATE9.          OFBEG148 DATE9.       
   OFBEG149 DATE9.          OFBEG150 DATE9.          OFBEG151 DATE9.       
   OFBEG152 DATE9.          OFBEG153 DATE9.          OFBEG154 DATE9.       
   OFBEG155 DATE9.          OFBEG156 DATE9.          OFBEG157 DATE9.       
   OFBEG158 DATE9.          OFBEG159 DATE9.          OFBEG160 DATE9.       
   OFBEG161 DATE9.          OFBEG162 DATE9.          OFBEG163 DATE9.       
   OFBEG164 DATE9.          OFBEG165 DATE9.          OFBEG166 DATE9.       
   OFBEG167 DATE9.          OFBEG168 DATE9.          OFBEG169 DATE9.       
   OFBEG170 DATE9.          OFBEG171 DATE9.          OFBEG172 DATE9.       
   OFBEG173 DATE9.          OFBEG174 DATE9.          OFBEG175 DATE9.       
   OFBEG176 DATE9.          OFBEG177 DATE9.          OFBEG178 DATE9.       
   OFBEG179 DATE9.          OFBEG180 DATE9.          OFBEG181 DATE9.       
   OFBEG182 DATE9.          OFBEG183 DATE9.          OFBEG184 DATE9.       
   OFBEG185 DATE9.          OFBEG186 DATE9.          OFBEG187 DATE9.       
   OFBEG188 DATE9.          OFBEG189 DATE9.          OFBEG190 DATE9.       
   OFBEG191 DATE9.          OFBEG192 DATE9.          OFBEG193 DATE9.       
   OFBEG194 DATE9.          OFBEG195 DATE9.          OFBEG196 DATE9.       
   OFBEG197 DATE9.          OFBEG198 DATE9.          OFBEG199 DATE9.       
   OFBEG200 DATE9.          OFBEG201 DATE9.          OFBEG202 DATE9.       
   OFBEG203 DATE9.          OFBEG204 DATE9.          OFBEG205 DATE9.       
   OFBEG206 DATE9.          OFBEG207 DATE9.          OFBEG208 DATE9.       
   OFBEG209 DATE9.          OFBEG210 DATE9.          OFBEG211 DATE9.       
   OFBEG212 DATE9.          OFBEG213 DATE9.          OFBEG214 DATE9.       
   OFBEG215 DATE9.          OFBEG216 DATE9.          OFBEG217 DATE9.       
   OFBEG218 DATE9.          OFBEG219 DATE9.          OFBEG220 DATE9.       
   OFBEG221 DATE9.          OFBEG222 DATE9.          OFBEG223 DATE9.       
   OFBEG224 DATE9.          OFBEG225 DATE9.          OFBEG226 DATE9.       
   OFBEG227 DATE9.          OFBEG228 DATE9.          OFBEG229 DATE9.       
   OFBEG230 DATE9.          OFBEG231 DATE9.          OFBEG232 DATE9.       
   OFBEG233 DATE9.          OFBEG234 DATE9.          OFBEG235 DATE9.       
   OFBEG236 DATE9.          OFBEG237 DATE9.          OFBEG238 DATE9.       
   OFBEG239 DATE9.          OFBEG240 DATE9.          OFBEG241 DATE9.       
   OFBEG242 DATE9.          OFBEG243 DATE9.          OFBEG244 DATE9.       
   OFBEG245 DATE9.          OFBEG246 DATE9.          OFBEG247 DATE9.       
   OFBEG248 DATE9.          OFBEG249 DATE9.          OFBEG250 DATE9.       
   OFBEG251 DATE9.          OFBEG252 DATE9.          OFBEG253 DATE9.       
   OFBEG254 DATE9.          OFBEG255 DATE9.          OFBEG256 DATE9.       
   OFBEG257 DATE9.          OFBEG258 DATE9.          OFBEG259 DATE9.       
   OFBEG260 DATE9.          OFBEG261 DATE9.          OFBEG262 DATE9.       
   OFBEG263 DATE9.          OFBEG264 DATE9.          OFBEG265 DATE9.       
   OFBEG266 DATE9.          OFEND1 DATE9.            OFEND2 DATE9.         
   OFEND3 DATE9.            OFEND4 DATE9.            OFEND5 DATE9.         
   OFEND6 DATE9.            OFEND7 DATE9.            OFEND8 DATE9.         
   OFEND9 DATE9.            OFEND10 DATE9.           OFEND11 DATE9.        
   OFEND12 DATE9.           OFEND13 DATE9.           OFEND14 DATE9.        
   OFEND15 DATE9.           OFEND16 DATE9.           OFEND17 DATE9.        
   OFEND18 DATE9.           OFEND19 DATE9.           OFEND20 DATE9.        
   OFEND21 DATE9.           OFEND22 DATE9.           OFEND23 DATE9.        
   OFEND24 DATE9.           OFEND25 DATE9.           OFEND26 DATE9.        
   OFEND27 DATE9.           OFEND28 DATE9.           OFEND29 DATE9.        
   OFEND30 DATE9.           OFEND31 DATE9.           OFEND32 DATE9.        
   OFEND33 DATE9.           OFEND34 DATE9.           OFEND35 DATE9.        
   OFEND36 DATE9.           OFEND37 DATE9.           OFEND38 DATE9.        
   OFEND39 DATE9.           OFEND40 DATE9.           OFEND41 DATE9.        
   OFEND42 DATE9.           OFEND43 DATE9.           OFEND44 DATE9.        
   OFEND45 DATE9.           OFEND46 DATE9.           OFEND47 DATE9.        
   OFEND48 DATE9.           OFEND49 DATE9.           OFEND50 DATE9.        
   OFEND51 DATE9.           OFEND52 DATE9.           OFEND53 DATE9.        
   OFEND54 DATE9.           OFEND55 DATE9.           OFEND56 DATE9.        
   OFEND57 DATE9.           OFEND58 DATE9.           OFEND59 DATE9.        
   OFEND60 DATE9.           OFEND61 DATE9.           OFEND62 DATE9.        
   OFEND63 DATE9.           OFEND64 DATE9.           OFEND65 DATE9.        
   OFEND66 DATE9.           OFEND67 DATE9.           OFEND68 DATE9.        
   OFEND69 DATE9.           OFEND70 DATE9.           OFEND71 DATE9.        
   OFEND72 DATE9.           OFEND73 DATE9.           OFEND74 DATE9.        
   OFEND75 DATE9.           OFEND76 DATE9.           OFEND77 DATE9.        
   OFEND78 DATE9.           OFEND79 DATE9.           OFEND80 DATE9.        
   OFEND81 DATE9.           OFEND82 DATE9.           OFEND83 DATE9.        
   OFEND84 DATE9.           OFEND85 DATE9.           OFEND86 DATE9.        
   OFEND87 DATE9.           OFEND88 DATE9.           OFEND89 DATE9.        
   OFEND90 DATE9.           OFEND91 DATE9.           OFEND92 DATE9.        
   OFEND93 DATE9.           OFEND94 DATE9.           OFEND95 DATE9.        
   OFEND96 DATE9.           OFEND97 DATE9.           OFEND98 DATE9.        
   OFEND99 DATE9.           OFEND100 DATE9.          OFEND101 DATE9.       
   OFEND102 DATE9.          OFEND103 DATE9.          OFEND104 DATE9.       
   OFEND105 DATE9.          OFEND106 DATE9.          OFEND107 DATE9.       
   OFEND108 DATE9.          OFEND109 DATE9.          OFEND110 DATE9.       
   OFEND111 DATE9.          OFEND112 DATE9.          OFEND113 DATE9.       
   OFEND114 DATE9.          OFEND115 DATE9.          OFEND116 DATE9.       
   OFEND117 DATE9.          OFEND118 DATE9.          OFEND119 DATE9.       
   OFEND120 DATE9.          OFEND121 DATE9.          OFEND122 DATE9.       
   OFEND123 DATE9.          OFEND124 DATE9.          OFEND125 DATE9.       
   OFEND126 DATE9.          OFEND127 DATE9.          OFEND128 DATE9.       
   OFEND129 DATE9.          OFEND130 DATE9.          OFEND131 DATE9.       
   OFEND132 DATE9.          OFEND133 DATE9.          OFEND134 DATE9.       
   OFEND135 DATE9.          OFEND136 DATE9.          OFEND137 DATE9.       
   OFEND138 DATE9.          OFEND139 DATE9.          OFEND140 DATE9.       
   OFEND141 DATE9.          OFEND142 DATE9.          OFEND143 DATE9.       
   OFEND144 DATE9.          OFEND145 DATE9.          OFEND146 DATE9.       
   OFEND147 DATE9.          OFEND148 DATE9.          OFEND149 DATE9.       
   OFEND150 DATE9.          OFEND151 DATE9.          OFEND152 DATE9.       
   OFEND153 DATE9.          OFEND154 DATE9.          OFEND155 DATE9.       
   OFEND156 DATE9.          OFEND157 DATE9.          OFEND158 DATE9.       
   OFEND159 DATE9.          OFEND160 DATE9.          OFEND161 DATE9.       
   OFEND162 DATE9.          OFEND163 DATE9.          OFEND164 DATE9.       
   OFEND165 DATE9.          OFEND166 DATE9.          OFEND167 DATE9.       
   OFEND168 DATE9.          OFEND169 DATE9.          OFEND170 DATE9.       
   OFEND171 DATE9.          OFEND172 DATE9.          OFEND173 DATE9.       
   OFEND174 DATE9.          OFEND175 DATE9.          OFEND176 DATE9.       
   OFEND177 DATE9.          OFEND178 DATE9.          OFEND179 DATE9.       
   OFEND180 DATE9.          OFEND181 DATE9.          OFEND182 DATE9.       
   OFEND183 DATE9.          OFEND184 DATE9.          OFEND185 DATE9.       
   OFEND186 DATE9.          OFEND187 DATE9.          OFEND188 DATE9.       
   OFEND189 DATE9.          OFEND190 DATE9.          OFEND191 DATE9.       
   OFEND192 DATE9.          OFEND193 DATE9.          OFEND194 DATE9.       
   OFEND195 DATE9.          OFEND196 DATE9.          OFEND197 DATE9.       
   OFEND198 DATE9.          OFEND199 DATE9.          OFEND200 DATE9.       
   OFEND201 DATE9.          OFEND202 DATE9.          OFEND203 DATE9.       
   OFEND204 DATE9.          OFEND205 DATE9.          OFEND206 DATE9.       
   OFEND207 DATE9.          OFEND208 DATE9.          OFEND209 DATE9.       
   OFEND210 DATE9.          OFEND211 DATE9.          OFEND212 DATE9.       
   OFEND213 DATE9.          OFEND214 DATE9.          OFEND215 DATE9.       
   OFEND216 DATE9.          OFEND217 DATE9.          OFEND218 DATE9.       
   OFEND219 DATE9.          OFEND220 DATE9.          OFEND221 DATE9.       
   OFEND222 DATE9.          OFEND223 DATE9.          OFEND224 DATE9.       
   OFEND225 DATE9.          OFEND226 DATE9.          OFEND227 DATE9.       
   OFEND228 DATE9.          OFEND229 DATE9.          OFEND230 DATE9.       
   OFEND231 DATE9.          OFEND232 DATE9.          OFEND233 DATE9.       
   OFEND234 DATE9.          OFEND235 DATE9.          OFEND236 DATE9.       
   OFEND237 DATE9.          OFEND238 DATE9.          OFEND239 DATE9.       
   OFEND240 DATE9.          OFEND241 DATE9.          OFEND242 DATE9.       
   OFEND243 DATE9.          OFEND244 DATE9.          OFEND245 DATE9.       
   OFEND246 DATE9.          OFEND247 DATE9.          OFEND248 DATE9.       
   OFEND249 DATE9.          OFEND250 DATE9.          OFEND251 DATE9.       
   OFEND252 DATE9.          OFEND253 DATE9.          OFEND254 DATE9.       
   OFEND255 DATE9.          OFEND256 DATE9.          OFEND257 DATE9.       
   OFEND258 DATE9.          OFEND259 DATE9.          OFEND260 DATE9.       
   OFEND261 DATE9.          OFEND262 DATE9.          OFEND263 DATE9.       
   OFEND264 DATE9.          OFEND265 DATE9.          OFEND266 DATE9.       
 ;
                     

LENGTH
   AMTFINEC 6               AMTREST 6                AMTTOTAL 6            
   COSTSUP 6                FINE 6                   USSCIDN 6             
   ACCAP 3                  ACCCAT 3                 ACCGDLN 3             
   ACCOFFLV 3               ACCTRESP 3               CAROFFAP 3            
   AGE 3                    ALTDUM 3                 ALTMO 3               
   AMENDYR 4                CAROFFLV 3               CHAP2 3               
   CIRCDIST 3               CITIZEN 3                CITWHERE 4            
   COADJLEV 3               COMBDRG2 3               COMDUM 3              
   COSTSDUM 3               CRIMHIST 3               CRIMLIV 3             
   CRIMPTS 4                DAYSDUM 3                DEFCONSL 3            
   DEPART 3                 DISPOSIT 3               DISTRICT 3            
   DRUGTYP1 4               DRUGTYP2 4               DRUGTYP3 4            
   DRUGTYP4 4               DRUGTYP5 4               DSIND 3               
   DSJANDC 3                DSPLEA 3                 DSPSR 3               
   DSSOR 3                  DUFROM1 3                DUFROM2 3             
   DUFROM3 3                DUFROM4 3                DUFROM5 3             
   DUTO1 3                  DUTO2 3                  DUTO3 3               
   DUTO4 3                  DUTO5 3                  ECONDUM 3             
   EDUCATN 3                ENCRYPT1 3               ENCRYPT2 3            
   FINECDUM 3               FINEWAIV 3               HISPORIG 3            
   HOMDUM 3                 HRCOMSRV 4               INOUT 3               
   INTDUM 3                 IS924C 3                 MARRIED 3             
   MOCOMCON 3               MOHOMDET 3               MOINTCON 3            
   MONCIRC 3                MONRACE 3                MONSEX 3              
   NEWCIT 3                 NEWCNVTN 3               NEWEDUC 3             
   NEWRACE 3                NOCOMP 3                 NOCOUNTS 4            
   NOUSTAT 3                NUMDEPEN 3               OFFTYPE2 3            
   POINT1 3                 POINT2 3                 POINT3 3              
   PRESENT 3                PRISDUM 3                PROBATN 4             
   PROBDUM 3                RANGEPT 3                REASON1 4             
   REASON2 4                REASON3 4                REL2PTS 3             
   RESNTDOC 3               RESTDUM 3                SAFE 3                
   SENTIMP 3                SENTPTS 3                SEXOFFNA 3            
   SEXOFFNB 3               SOURCES 3                SUPRDUM 3             
   SUPREL 4                 TOTCHPTS 3               TOTDAYS 3             
   TYPEMONY 3               TYPEOTHS 3               UNIT1 3               
   UNIT2 3                  UNIT3 3                  UNIT4 3               
   UNIT5 3                  VIOL1PTS 3               WEAPON 3              
   WEAPSOC 3                XCRHISSR 3               XFOLSOR 3             
   YEARS 3                  DRUGMIN 4                GLMIN 4               
   GLMAX 4                  GUNMIN1 4                GUNMIN2 4             
   STATMAX 6                STATMIN 4                TOTPRISN 4            
   XMAXSOR 4                XMINSOR 4                SMIN1 4               
   SMIN2 4                  SMIN3 4                  SMIN4 4               
   SMIN5 4                  SMIN6 4                  SMIN7 4               
   SMIN8 4                  SMIN9 4                  SMIN10 4              
   SMIN11 4                 SMIN12 4                 SMIN13 4              
   SMIN14 4                 SMIN15 4                 SMIN16 4              
   SMIN17 4                 SMIN18 4                 SMIN19 4              
   SMIN20 4                 SMIN21 4                 SMIN22 4              
   SMIN23 4                 SMIN24 4                 SMIN25 4              
   SMIN26 4                 SMIN27 4                 SMIN28 4              
   SMIN29 4                 SMIN30 4                 SMIN31 4              
   SMIN32 4                 SMIN33 4                 SMIN34 4              
   SMIN35 4                 SMIN36 4                 SMIN37 4              
   SMIN38 4                 SMIN39 4                 SMIN40 4              
   SMIN41 4                 SMIN42 4                 SMIN43 4              
   SMIN44 4                 SMIN45 4                 SMIN46 4              
   SMIN47 4                 SMIN48 4                 SMIN49 4              
   SMIN50 4                 SMIN51 4                 SMIN52 4              
   SMIN53 4                 SMIN54 4                 SMIN55 4              
   SMIN56 4                 SMIN57 4                 SMIN58 4              
   SMIN59 4                 SMIN60 4                 SMIN61 4              
   SMIN62 4                 SMIN63 4                 SMIN64 4              
   SMIN65 4                 SMIN66 4                 SMIN67 4              
   SMIN68 4                 SMIN69 4                 SMIN70 4              
   SMIN71 4                 SMIN72 4                 SMIN73 4              
   SMIN74 4                 SMIN75 4                 SMIN76 4              
   SMIN77 4                 SMIN78 4                 SMIN79 4              
   SMIN80 4                 SMIN81 4                 SMIN82 4              
   SMIN83 4                 SMIN84 4                 SMIN85 4              
   SMIN86 4                 SMIN87 4                 SMIN88 4              
   SMIN89 4                 SMIN90 4                 SMIN91 4              
   SMIN92 4                 SMIN93 4                 SMIN94 4              
   SMIN95 4                 SMIN96 4                 SMIN97 4              
   SMIN98 4                 SMIN99 4                 SMIN100 4             
   SMIN101 4                SMIN102 4                SMIN103 4             
   SMIN104 4                SMIN105 4                SMIN106 4             
   SMIN107 4                SMIN108 4                SMIN109 4             
   SMIN110 4                SMIN111 4                SMIN112 4             
   SMIN113 4                SMIN114 4                SMIN115 4             
   SMIN116 4                SMIN117 4                SMIN118 4             
   SMIN119 4                SMIN120 4                SMIN121 4             
   SMIN122 4                SMIN123 4                SMIN124 4             
   SMIN125 4                SMIN126 4                SMIN127 4             
   SMIN128 4                SMIN129 4                SMIN130 4             
   SMIN131 4                SMIN132 4                SMIN133 4             
   SMIN134 4                SMIN135 4                SMIN136 4             
   SMIN137 4                SMIN138 4                SMIN139 4             
   SMIN140 4                SMIN141 4                SMIN142 4             
   SMIN143 4                SMIN144 4                SMIN145 4             
   SMIN146 4                SMIN147 4                SMIN148 4             
   SMIN149 4                SMIN150 4                SMIN151 4             
   SMIN152 4                SMIN153 4                SMIN154 4             
   SMIN155 4                SMIN156 4                SMIN157 4             
   SMIN158 4                SMIN159 4                SMIN160 4             
   SMIN161 4                SMIN162 4                SMIN163 4             
   SMIN164 4                SMIN165 4                SMIN166 4             
   SMIN167 4                SMIN168 4                SMIN169 4             
   SMIN170 4                SMIN171 4                SMIN172 4             
   SMIN173 4                SMIN174 4                SMIN175 4             
   SMIN176 4                SMIN177 4                SMIN178 4             
   SMIN179 4                SMIN180 4                SMIN181 4             
   SMIN182 4                SMIN183 4                SMIN184 4             
   SMIN185 4                SMIN186 4                SMIN187 4             
   SMIN188 4                SMIN189 4                SMIN190 4             
   SMIN191 4                SMIN192 4                SMIN193 4             
   SMIN194 4                SMIN195 4                SMIN196 4             
   SMIN197 4                SMIN198 4                SMIN199 4             
   SMIN200 4                SMIN201 4                SMIN202 4             
   SMIN203 4                SMIN204 4                SMIN205 4             
   SMIN206 4                SMIN207 4                SMIN208 4             
   SMIN209 4                SMIN210 4                SMIN211 4             
   SMIN212 4                SMIN213 4                SMIN214 4             
   SMIN215 4                SMIN216 4                SMIN217 4             
   SMIN218 4                SMIN219 4                SMIN220 4             
   SMIN221 4                SMIN222 4                SMIN223 4             
   SMIN224 4                SMIN225 4                SMIN226 4             
   SMIN227 4                SMIN228 4                SMIN229 4             
   SMIN230 4                SMIN231 4                SMIN232 4             
   SMIN233 4                SMIN234 4                SMIN235 4             
   SMIN236 4                SMIN237 4                SMIN238 4             
   SMIN239 4                SMIN240 4                SMIN241 4             
   SMIN242 4                SMIN243 4                SMIN244 4             
   SMIN245 4                SMIN246 4                SMIN247 4             
   SMIN248 4                SMIN249 4                SMIN250 4             
   SMIN251 4                SMIN252 4                SMIN253 4             
   SMIN254 4                SMIN255 4                SMIN256 4             
   SMIN257 4                SMIN258 4                SMIN259 4             
   SMIN260 4                SMIN261 4                SMIN262 4             
   SMIN263 4                SMIN264 4                SMIN265 4             
   SMIN266 4                SMAX1 4                  SMAX2 4               
   SMAX3 4                  SMAX4 4                  SMAX5 4               
   SMAX6 4                  SMAX7 4                  SMAX8 4               
   SMAX9 4                  SMAX10 4                 SMAX11 4              
   SMAX12 4                 SMAX13 4                 SMAX14 4              
   SMAX15 4                 SMAX16 4                 SMAX17 4              
   SMAX18 4                 SMAX19 4                 SMAX20 4              
   SMAX21 4                 SMAX22 4                 SMAX23 4              
   SMAX24 4                 SMAX25 4                 SMAX26 4              
   SMAX27 4                 SMAX28 4                 SMAX29 4              
   SMAX30 4                 SMAX31 4                 SMAX32 4              
   SMAX33 4                 SMAX34 4                 SMAX35 4              
   SMAX36 4                 SMAX37 4                 SMAX38 4              
   SMAX39 4                 SMAX40 4                 SMAX41 4              
   SMAX42 4                 SMAX43 4                 SMAX44 4              
   SMAX45 4                 SMAX46 4                 SMAX47 4              
   SMAX48 4                 SMAX49 4                 SMAX50 4              
   SMAX51 4                 SMAX52 4                 SMAX53 4              
   SMAX54 4                 SMAX55 4                 SMAX56 4              
   SMAX57 4                 SMAX58 4                 SMAX59 4              
   SMAX60 4                 SMAX61 4                 SMAX62 4              
   SMAX63 4                 SMAX64 4                 SMAX65 4              
   SMAX66 4                 SMAX67 4                 SMAX68 4              
   SMAX69 4                 SMAX70 4                 SMAX71 4              
   SMAX72 4                 SMAX73 4                 SMAX74 4              
   SMAX75 4                 SMAX76 4                 SMAX77 4              
   SMAX78 4                 SMAX79 4                 SMAX80 4              
   SMAX81 4                 SMAX82 4                 SMAX83 4              
   SMAX84 4                 SMAX85 4                 SMAX86 4              
   SMAX87 4                 SMAX88 4                 SMAX89 4              
   SMAX90 4                 SMAX91 4                 SMAX92 4              
   SMAX93 4                 SMAX94 4                 SMAX95 4              
   SMAX96 4                 SMAX97 4                 SMAX98 4              
   SMAX99 4                 SMAX100 4                SMAX101 4             
   SMAX102 4                SMAX103 4                SMAX104 4             
   SMAX105 4                SMAX106 4                SMAX107 4             
   SMAX108 4                SMAX109 4                SMAX110 4             
   SMAX111 4                SMAX112 4                SMAX113 4             
   SMAX114 4                SMAX115 4                SMAX116 4             
   SMAX117 4                SMAX118 4                SMAX119 4             
   SMAX120 4                SMAX121 4                SMAX122 4             
   SMAX123 4                SMAX124 4                SMAX125 4             
   SMAX126 4                SMAX127 4                SMAX128 4             
   SMAX129 4                SMAX130 4                SMAX131 4             
   SMAX132 4                SMAX133 4                SMAX134 4             
   SMAX135 4                SMAX136 4                SMAX137 4             
   SMAX138 4                SMAX139 4                SMAX140 4             
   SMAX141 4                SMAX142 4                SMAX143 4             
   SMAX144 4                SMAX145 4                SMAX146 4             
   SMAX147 4                SMAX148 4                SMAX149 4             
   SMAX150 4                SMAX151 4                SMAX152 4             
   SMAX153 4                SMAX154 4                SMAX155 4             
   SMAX156 4                SMAX157 4                SMAX158 4             
   SMAX159 4                SMAX160 4                SMAX161 4             
   SMAX162 4                SMAX163 4                SMAX164 4             
   SMAX165 4                SMAX166 4                SMAX167 4             
   SMAX168 4                SMAX169 4                SMAX170 4             
   SMAX171 4                SMAX172 4                SMAX173 4             
   SMAX174 4                SMAX175 4                SMAX176 4             
   SMAX177 4                SMAX178 4                SMAX179 4             
   SMAX180 4                SMAX181 4                SMAX182 4             
   SMAX183 4                SMAX184 4                SMAX185 4             
   SMAX186 4                SMAX187 4                SMAX188 4             
   SMAX189 4                SMAX190 4                SMAX191 4             
   SMAX192 4                SMAX193 4                SMAX194 4             
   SMAX195 4                SMAX196 4                SMAX197 4             
   SMAX198 4                SMAX199 4                SMAX200 4             
   SMAX201 4                SMAX202 4                SMAX203 4             
   SMAX204 4                SMAX205 4                SMAX206 4             
   SMAX207 4                SMAX208 4                SMAX209 4             
   SMAX210 4                SMAX211 4                SMAX212 4             
   SMAX213 4                SMAX214 4                SMAX215 4             
   SMAX216 4                SMAX217 4                SMAX218 4             
   SMAX219 4                SMAX220 4                SMAX221 4             
   SMAX222 4                SMAX223 4                SMAX224 4             
   SMAX225 4                SMAX226 4                SMAX227 4             
   SMAX228 4                SMAX229 4                SMAX230 4             
   SMAX231 4                SMAX232 4                SMAX233 4             
   SMAX234 4                SMAX235 4                SMAX236 4             
   SMAX237 4                SMAX238 4                SMAX239 4             
   SMAX240 4                SMAX241 4                SMAX242 4             
   SMAX243 4                SMAX244 4                SMAX245 4             
   SMAX246 4                SMAX247 4                SMAX248 4             
   SMAX249 4                SMAX250 4                SMAX251 4             
   SMAX252 4                SMAX253 4                SMAX254 4             
   SMAX255 4                SMAX256 4                SMAX257 4             
   SMAX258 4                SMAX259 4                SMAX260 4             
   SMAX261 4                SMAX262 4                SMAX263 4             
   SMAX264 4                SMAX265 4                SMAX266 4             
   TIMSERVD 4               TIMSERVM 4               SPECASSM 6            
   CHMAM3 3                 CHMAM4 3                 CHMAM5 3              
   CUNIT1 3                 CUNIT2 3                 CUNIT3 3              
   CUNIT4 3                 CUNIT5 3                 CHEMTYP1 3            
   CHEMTYP2 3               CHEMTYP3 3               CHEMTYP4 3            
   CHEMTYP5 3               CAFROM2 3                CAFROM3 3             
   CAFROM4 3                CAFROM5 3                CATO1 4               
   CATO2 3                  CATO3 3                  CATO4 3               
   CATO5 3                  ABUS1 3                  ABUS2 3               
   ABUS3 3                  ABUS4 3                  ABUS5 3               
   ABUS6 3                  ABUS7 3                  ABUS8 3               
   ABUS9 3                  ABUS10 3                 ABUS11 3              
   ABUS12 3                 ABUS13 3                 ABUS14 3              
   ABUS15 3                 ABUS16 3                 ABUS17 3              
   ABUS18 3                 ABUS19 3                 ABUS20 3              
   ABUS21 3                 ABUS22 3                 ABUS23 3              
   ABUS24 3                 ABUS25 3                 ABUS26 3              
   ABUS27 3                 ABUSHI 3                 ABUSR1 3              
   ABUSR2 3                 ABUSR3 3                 ABUSR4 3              
   ABUSR5 3                 ABUSR6 3                 ABUSR7 3              
   ABUSR8 3                 ABUSR9 3                 ABUSR10 3             
   ABUSR11 3                ABUSR12 3                ABUSR13 3             
   ABUSR14 3                ABUSR15 3                ABUSR16 3             
   ABUSR17 3                ABUSR18 3                ABUSR19 3             
   ABUSR20 3                ABUSR21 3                ABUSR22 3             
   ABUSR23 3                ABUSR24 3                ABUSR25 3             
   ABUSR26 3                ABUSR27 3                ABUSRHI 3             
   ADJOFL1 3                ADJOFL2 3                ADJOFL3 3             
   ADJOFL4 3                ADJOFL5 3                ADJOFL6 3             
   ADJOFL7 3                ADJOFL8 3                ADJOFL9 3             
   ADJOFL10 3               ADJOFL11 3               ADJOFL12 3            
   ADJOFL13 3               ADJOFL14 3               ADJOFL15 3            
   ADJOFL16 3               ADJOFL17 3               ADJOFL18 3            
   ADJOFL19 3               ADJOFL20 3               ADJOFL21 3            
   ADJOFL22 3               ADJOFL23 3               ADJOFL24 3            
   ADJOFL25 3               ADJOFL26 3               ADJOFL27 3            
   ADJOFLHI 3               ADJOFR1 3                ADJOFR2 3             
   ADJOFR3 3                ADJOFR4 3                ADJOFR5 3             
   ADJOFR6 3                ADJOFR7 3                ADJOFR8 3             
   ADJOFR9 3                ADJOFR10 3               ADJOFR11 3            
   ADJOFR12 3               ADJOFR13 3               ADJOFR14 3            
   ADJOFR15 3               ADJOFR16 3               ADJOFR17 3            
   ADJOFR18 3               ADJOFR19 3               ADJOFR20 3            
   ADJOFR21 3               ADJOFR22 3               ADJOFR23 3            
   ADJOFR24 3               ADJOFR25 3               ADJOFR26 3            
   ADJOFR27 3               ADJOFRHI 3               ADJR_B1 3             
   ADJR_B2 3                ADJR_B3 3                ADJR_B4 3             
   ADJR_B5 3                ADJR_B6 3                ADJR_B7 3             
   ADJR_B8 3                ADJR_B9 3                ADJR_B10 3            
   ADJR_B11 3               ADJR_B12 3               ADJR_B13 3            
   ADJR_B14 3               ADJR_B15 3               ADJR_B16 3            
   ADJR_B17 3               ADJR_B18 3               ADJR_B19 3            
   ADJR_B20 3               ADJR_B21 3               ADJR_B22 3            
   ADJR_B23 3               ADJR_B24 3               ADJR_B25 3            
   ADJR_B26 3               ADJR_B27 3               ADJR_BHI 3            
   ADJR_C1 3                ADJR_C2 3                ADJR_C3 3             
   ADJR_C4 3                ADJR_C5 3                ADJR_C6 3             
   ADJR_C7 3                ADJR_C8 3                ADJR_C9 3             
   ADJR_C10 3               ADJR_C11 3               ADJR_C12 3            
   ADJR_C13 3               ADJR_C14 3               ADJR_C15 3            
   ADJR_C16 3               ADJR_C17 3               ADJR_C18 3            
   ADJR_C19 3               ADJR_C20 3               ADJR_C21 3            
   ADJR_C22 3               ADJR_C23 3               ADJR_C24 3            
   ADJR_C25 3               ADJR_C26 3               ADJR_C27 3            
   ADJR_CHI 3               ADJR_D1 3                ADJR_D2 3             
   ADJR_D3 3                ADJR_D4 3                ADJR_D5 3             
   ADJR_D6 3                ADJR_D7 3                ADJR_D8 3             
   ADJR_D9 3                ADJR_D10 3               ADJR_D11 3            
   ADJR_D12 3               ADJR_D13 3               ADJR_D14 3            
   ADJR_D15 3               ADJR_D16 3               ADJR_D17 3            
   ADJR_D18 3               ADJR_D19 3               ADJR_D20 3            
   ADJR_D21 3               ADJR_D22 3               ADJR_D23 3            
   ADJR_D24 3               ADJR_D25 3               ADJR_D26 3            
   ADJR_D27 3               ADJR_DHI 3               ADJR_E1 3             
   ADJR_E2 3                ADJR_E3 3                ADJR_E4 3             
   ADJR_E5 3                ADJR_E6 3                ADJR_E7 3             
   ADJR_E8 3                ADJR_E9 3                ADJR_E10 3            
   ADJR_E11 3               ADJR_E12 3               ADJR_E13 3            
   ADJR_E14 3               ADJR_E15 3               ADJR_E16 3            
   ADJR_E17 3               ADJR_E18 3               ADJR_E19 3            
   ADJR_E20 3               ADJR_E21 3               ADJR_E22 3            
   ADJR_E23 3               ADJR_E24 3               ADJR_E25 3            
   ADJR_E26 3               ADJR_E27 3               ADJR_EHI 3            
   ADJR_F1 3                ADJR_F2 3                ADJR_F3 3             
   ADJR_F4 3                ADJR_F5 3                ADJR_F6 3             
   ADJR_F7 3                ADJR_F8 3                ADJR_F9 3             
   ADJR_F10 3               ADJR_F11 3               ADJR_F12 3            
   ADJR_F13 3               ADJR_F14 3               ADJR_F15 3            
   ADJR_F16 3               ADJR_F17 3               ADJR_F18 3            
   ADJR_F19 3               ADJR_F20 3               ADJR_F21 3            
   ADJR_F22 3               ADJR_F23 3               ADJR_F24 3            
   ADJR_F25 3               ADJR_F26 3               ADJR_F27 3            
   ADJR_FHI 3               ADJR_G1 3                ADJR_G2 3             
   ADJR_G3 3                ADJR_G4 3                ADJR_G5 3             
   ADJR_G6 3                ADJR_G7 3                ADJR_G8 3             
   ADJR_G9 3                ADJR_G10 3               ADJR_G11 3            
   ADJR_G12 3               ADJR_G13 3               ADJR_G14 3            
   ADJR_G15 3               ADJR_G16 3               ADJR_G17 3            
   ADJR_G18 3               ADJR_G19 3               ADJR_G20 3            
   ADJR_G21 3               ADJR_G22 3               ADJR_G23 3            
   ADJR_G24 3               ADJR_G25 3               ADJR_G26 3            
   ADJR_G27 3               ADJR_GHI 3               ADJR_H1 3             
   ADJR_H2 3                ADJR_H3 3                ADJR_H4 3             
   ADJR_H5 3                ADJR_H6 3                ADJR_H7 3             
   ADJR_H8 3                ADJR_H9 3                ADJR_H10 3            
   ADJR_H11 3               ADJR_H12 3               ADJR_H13 3            
   ADJR_H14 3               ADJR_H15 3               ADJR_H16 3            
   ADJR_H17 3               ADJR_H18 3               ADJR_H19 3            
   ADJR_H20 3               ADJR_H21 3               ADJR_H22 3            
   ADJR_H23 3               ADJR_H24 3               ADJR_H25 3            
   ADJR_H26 3               ADJR_H27 3               ADJR_HHI 3            
   ADJR_I1 3                ADJR_I2 3                ADJR_I3 3             
   ADJR_I4 3                ADJR_I5 3                ADJR_I6 3             
   ADJR_I7 3                ADJR_I8 3                ADJR_I9 3             
   ADJR_I10 3               ADJR_I11 3               ADJR_I12 3            
   ADJR_I13 3               ADJR_I14 3               ADJR_I15 3            
   ADJR_I16 3               ADJR_I17 3               ADJR_I18 3            
   ADJR_I19 3               ADJR_I20 3               ADJR_I21 3            
   ADJR_I22 3               ADJR_I23 3               ADJR_I24 3            
   ADJR_I25 3               ADJR_I26 3               ADJR_I27 3            
   ADJR_IHI 3               ADJR_J1 3                ADJR_J2 3             
   ADJR_J3 3                ADJR_J4 3                ADJR_J5 3             
   ADJR_J6 3                ADJR_J7 3                ADJR_J8 3             
   ADJR_J9 3                ADJR_J10 3               ADJR_J11 3            
   ADJR_J12 3               ADJR_J13 3               ADJR_J14 3            
   ADJR_J15 3               ADJR_J16 3               ADJR_J17 3            
   ADJR_J18 3               ADJR_J19 3               ADJR_J20 3            
   ADJR_J21 3               ADJR_J22 3               ADJR_J23 3            
   ADJR_J24 3               ADJR_J25 3               ADJR_J26 3            
   ADJR_J27 3               ADJR_JHI 3               ADJR_K1 3             
   ADJR_K2 3                ADJR_K3 3                ADJR_K4 3             
   ADJR_K5 3                ADJR_K6 3                ADJR_K7 3             
   ADJR_K8 3                ADJR_K9 3                ADJR_K10 3            
   ADJR_K11 3               ADJR_K12 3               ADJR_K13 3            
   ADJR_K14 3               ADJR_K15 3               ADJR_K16 3            
   ADJR_K17 3               ADJR_K18 3               ADJR_K19 3            
   ADJR_K20 3               ADJR_K21 3               ADJR_K22 3            
   ADJR_K23 3               ADJR_K24 3               ADJR_K25 3            
   ADJR_K26 3               ADJR_K27 3               ADJR_KHI 3            
   ADJR_L1 3                ADJR_L2 3                ADJR_L3 3             
   ADJR_L4 3                ADJR_L5 3                ADJR_L6 3             
   ADJR_L7 3                ADJR_L8 3                ADJR_L9 3             
   ADJR_L10 3               ADJR_L11 3               ADJR_L12 3            
   ADJR_L13 3               ADJR_L14 3               ADJR_L15 3            
   ADJR_L16 3               ADJR_L17 3               ADJR_L18 3            
   ADJR_L19 3               ADJR_L20 3               ADJR_L21 3            
   ADJR_L22 3               ADJR_L23 3               ADJR_L24 3            
   ADJR_L25 3               ADJR_L26 3               ADJR_L27 3            
   ADJR_LHI 3               ADJR_M1 3                ADJR_M2 3             
   ADJR_M3 3                ADJR_M4 3                ADJR_M5 3             
   ADJR_M6 3                ADJR_M7 3                ADJR_M8 3             
   ADJR_M9 3                ADJR_M10 3               ADJR_M11 3            
   ADJR_M12 3               ADJR_M13 3               ADJR_M14 3            
   ADJR_M15 3               ADJR_M16 3               ADJR_M17 3            
   ADJR_M18 3               ADJR_M19 3               ADJR_M20 3            
   ADJR_M21 3               ADJR_M22 3               ADJR_M23 3            
   ADJR_M24 3               ADJR_M25 3               ADJR_M26 3            
   ADJR_M27 3               ADJR_MHI 3               ADJR_N1 3             
   ADJR_N2 3                ADJR_N3 3                ADJR_N4 3             
   ADJR_N5 3                ADJR_N6 3                ADJR_N7 3             
   ADJR_N8 3                ADJR_N9 3                ADJR_N10 3            
   ADJR_N11 3               ADJR_N12 3               ADJR_N13 3            
   ADJR_N14 3               ADJR_N15 3               ADJR_N16 3            
   ADJR_N17 3               ADJR_N18 3               ADJR_N19 3            
   ADJR_N20 3               ADJR_N21 3               ADJR_N22 3            
   ADJR_N23 3               ADJR_N24 3               ADJR_N25 3            
   ADJR_N26 3               ADJR_N27 3               ADJR_NHI 3            
   ADJR_O1 3                ADJR_O2 3                ADJR_O3 3             
   ADJR_O4 3                ADJR_O5 3                ADJR_O6 3             
   ADJR_O7 3                ADJR_O8 3                ADJR_O9 3             
   ADJR_O10 3               ADJR_O11 3               ADJR_O12 3            
   ADJR_O13 3               ADJR_O14 3               ADJR_O15 3            
   ADJR_O16 3               ADJR_O17 3               ADJR_O18 3            
   ADJR_O19 3               ADJR_O20 3               ADJR_O21 3            
   ADJR_O22 3               ADJR_O23 3               ADJR_O24 3            
   ADJR_O25 3               ADJR_O26 3               ADJR_O27 3            
   ADJR_OHI 3               ADJR_P1 3                ADJR_P2 3             
   ADJR_P3 3                ADJR_P4 3                ADJR_P5 3             
   ADJR_P6 3                ADJR_P7 3                ADJR_P8 3             
   ADJR_P9 3                ADJR_P10 3               ADJR_P11 3            
   ADJR_P12 3               ADJR_P13 3               ADJR_P14 3            
   ADJR_P15 3               ADJR_P16 3               ADJR_P17 3            
   ADJR_P18 3               ADJR_P19 3               ADJR_P20 3            
   ADJR_P21 3               ADJR_P22 3               ADJR_P23 3            
   ADJR_P24 3               ADJR_P25 3               ADJR_P26 3            
   ADJR_P27 3               ADJR_PHI 3               ADJ_B1 3              
   ADJ_B2 3                 ADJ_B3 3                 ADJ_B4 3              
   ADJ_B5 3                 ADJ_B6 3                 ADJ_B7 3              
   ADJ_B8 3                 ADJ_B9 3                 ADJ_B10 3             
   ADJ_B11 3                ADJ_B12 3                ADJ_B13 3             
   ADJ_B14 3                ADJ_B15 3                ADJ_B16 3             
   ADJ_B17 3                ADJ_B18 3                ADJ_B19 3             
   ADJ_B20 3                ADJ_B21 3                ADJ_B22 3             
   ADJ_B23 3                ADJ_B24 3                ADJ_B25 3             
   ADJ_B26 3                ADJ_B27 3                ADJ_BHI 3             
   ADJ_C1 3                 ADJ_C2 3                 ADJ_C3 3              
   ADJ_C4 3                 ADJ_C5 3                 ADJ_C6 3              
   ADJ_C7 3                 ADJ_C8 3                 ADJ_C9 3              
   ADJ_C10 3                ADJ_C11 3                ADJ_C12 3             
   ADJ_C13 3                ADJ_C14 3                ADJ_C15 3             
   ADJ_C16 3                ADJ_C17 3                ADJ_C18 3             
   ADJ_C19 3                ADJ_C20 3                ADJ_C21 3             
   ADJ_C22 3                ADJ_C23 3                ADJ_C24 3             
   ADJ_C25 3                ADJ_C26 3                ADJ_C27 3             
   ADJ_CHI 3                ADJ_D1 3                 ADJ_D2 3              
   ADJ_D3 3                 ADJ_D4 3                 ADJ_D5 3              
   ADJ_D6 3                 ADJ_D7 3                 ADJ_D8 3              
   ADJ_D9 3                 ADJ_D10 3                ADJ_D11 3             
   ADJ_D12 3                ADJ_D13 3                ADJ_D14 3             
   ADJ_D15 3                ADJ_D16 3                ADJ_D17 3             
   ADJ_D18 3                ADJ_D19 3                ADJ_D20 3             
   ADJ_D21 3                ADJ_D22 3                ADJ_D23 3             
   ADJ_D24 3                ADJ_D25 3                ADJ_D26 3             
   ADJ_D27 3                ADJ_DHI 3                ADJ_E1 3              
   ADJ_E2 3                 ADJ_E3 3                 ADJ_E4 3              
   ADJ_E5 3                 ADJ_E6 3                 ADJ_E7 3              
   ADJ_E8 3                 ADJ_E9 3                 ADJ_E10 3             
   ADJ_E11 3                ADJ_E12 3                ADJ_E13 3             
   ADJ_E14 3                ADJ_E15 3                ADJ_E16 3             
   ADJ_E17 3                ADJ_E18 3                ADJ_E19 3             
   ADJ_E20 3                ADJ_E21 3                ADJ_E22 3             
   ADJ_E23 3                ADJ_E24 3                ADJ_E25 3             
   ADJ_E26 3                ADJ_E27 3                ADJ_EHI 3             
   ADJ_F1 3                 ADJ_F2 3                 ADJ_F3 3              
   ADJ_F4 3                 ADJ_F5 3                 ADJ_F6 3              
   ADJ_F7 3                 ADJ_F8 3                 ADJ_F9 3              
   ADJ_F10 3                ADJ_F11 3                ADJ_F12 3             
   ADJ_F13 3                ADJ_F14 3                ADJ_F15 3             
   ADJ_F16 3                ADJ_F17 3                ADJ_F18 3             
   ADJ_F19 3                ADJ_F20 3                ADJ_F21 3             
   ADJ_F22 3                ADJ_F23 3                ADJ_F24 3             
   ADJ_F25 3                ADJ_F26 3                ADJ_F27 3             
   ADJ_FHI 3                ADJ_G1 3                 ADJ_G2 3              
   ADJ_G3 3                 ADJ_G4 3                 ADJ_G5 3              
   ADJ_G6 3                 ADJ_G7 3                 ADJ_G8 3              
   ADJ_G9 3                 ADJ_G10 3                ADJ_G11 3             
   ADJ_G12 3                ADJ_G13 3                ADJ_G14 3             
   ADJ_G15 3                ADJ_G16 3                ADJ_G17 3             
   ADJ_G18 3                ADJ_G19 3                ADJ_G20 3             
   ADJ_G21 3                ADJ_G22 3                ADJ_G23 3             
   ADJ_G24 3                ADJ_G25 3                ADJ_G26 3             
   ADJ_G27 3                ADJ_GHI 3                ADJ_H1 3              
   ADJ_H2 3                 ADJ_H3 3                 ADJ_H4 3              
   ADJ_H5 3                 ADJ_H6 3                 ADJ_H7 3              
   ADJ_H8 3                 ADJ_H9 3                 ADJ_H10 3             
   ADJ_H11 3                ADJ_H12 3                ADJ_H13 3             
   ADJ_H14 3                ADJ_H15 3                ADJ_H16 3             
   ADJ_H17 3                ADJ_H18 3                ADJ_H19 3             
   ADJ_H20 3                ADJ_H21 3                ADJ_H22 3             
   ADJ_H23 3                ADJ_H24 3                ADJ_H25 3             
   ADJ_H26 3                ADJ_H27 3                ADJ_HHI 3             
   ADJ_I1 3                 ADJ_I2 3                 ADJ_I3 3              
   ADJ_I4 3                 ADJ_I5 3                 ADJ_I6 3              
   ADJ_I7 3                 ADJ_I8 3                 ADJ_I9 3              
   ADJ_I10 3                ADJ_I11 3                ADJ_I12 3             
   ADJ_I13 3                ADJ_I14 3                ADJ_I15 3             
   ADJ_I16 3                ADJ_I17 3                ADJ_I18 3             
   ADJ_I19 3                ADJ_I20 3                ADJ_I21 3             
   ADJ_I22 3                ADJ_I23 3                ADJ_I24 3             
   ADJ_I25 3                ADJ_I26 3                ADJ_I27 3             
   ADJ_IHI 3                ADJ_J1 3                 ADJ_J2 3              
   ADJ_J3 3                 ADJ_J4 3                 ADJ_J5 3              
   ADJ_J6 3                 ADJ_J7 3                 ADJ_J8 3              
   ADJ_J9 3                 ADJ_J10 3                ADJ_J11 3             
   ADJ_J12 3                ADJ_J13 3                ADJ_J14 3             
   ADJ_J15 3                ADJ_J16 3                ADJ_J17 3             
   ADJ_J18 3                ADJ_J19 3                ADJ_J20 3             
   ADJ_J21 3                ADJ_J22 3                ADJ_J23 3             
   ADJ_J24 3                ADJ_J25 3                ADJ_J26 3             
   ADJ_J27 3                ADJ_JHI 3                ADJ_K1 3              
   ADJ_K2 3                 ADJ_K3 3                 ADJ_K4 3              
   ADJ_K5 3                 ADJ_K6 3                 ADJ_K7 3              
   ADJ_K8 3                 ADJ_K9 3                 ADJ_K10 3             
   ADJ_K11 3                ADJ_K12 3                ADJ_K13 3             
   ADJ_K14 3                ADJ_K15 3                ADJ_K16 3             
   ADJ_K17 3                ADJ_K18 3                ADJ_K19 3             
   ADJ_K20 3                ADJ_K21 3                ADJ_K22 3             
   ADJ_K23 3                ADJ_K24 3                ADJ_K25 3             
   ADJ_K26 3                ADJ_K27 3                ADJ_KHI 3             
   ADJ_L1 3                 ADJ_L2 3                 ADJ_L3 3              
   ADJ_L4 3                 ADJ_L5 3                 ADJ_L6 3              
   ADJ_L7 3                 ADJ_L8 3                 ADJ_L9 3              
   ADJ_L10 3                ADJ_L11 3                ADJ_L12 3             
   ADJ_L13 3                ADJ_L14 3                ADJ_L15 3             
   ADJ_L16 3                ADJ_L17 3                ADJ_L18 3             
   ADJ_L19 3                ADJ_L20 3                ADJ_L21 3             
   ADJ_L22 3                ADJ_L23 3                ADJ_L24 3             
   ADJ_L25 3                ADJ_L26 3                ADJ_L27 3             
   ADJ_LHI 3                ADJ_M1 3                 ADJ_M2 3              
   ADJ_M3 3                 ADJ_M4 3                 ADJ_M5 3              
   ADJ_M6 3                 ADJ_M7 3                 ADJ_M8 3              
   ADJ_M9 3                 ADJ_M10 3                ADJ_M11 3             
   ADJ_M12 3                ADJ_M13 3                ADJ_M14 3             
   ADJ_M15 3                ADJ_M16 3                ADJ_M17 3             
   ADJ_M18 3                ADJ_M19 3                ADJ_M20 3             
   ADJ_M21 3                ADJ_M22 3                ADJ_M23 3             
   ADJ_M24 3                ADJ_M25 3                ADJ_M26 3             
   ADJ_M27 3                ADJ_MHI 3                ADJ_N1 3              
   ADJ_N2 3                 ADJ_N3 3                 ADJ_N4 3              
   ADJ_N5 3                 ADJ_N6 3                 ADJ_N7 3              
   ADJ_N8 3                 ADJ_N9 3                 ADJ_N10 3             
   ADJ_N11 3                ADJ_N12 3                ADJ_N13 3             
   ADJ_N14 3                ADJ_N15 3                ADJ_N16 3             
   ADJ_N17 3                ADJ_N18 3                ADJ_N19 3             
   ADJ_N20 3                ADJ_N21 3                ADJ_N22 3             
   ADJ_N23 3                ADJ_N24 3                ADJ_N25 3             
   ADJ_N26 3                ADJ_N27 3                ADJ_NHI 3             
   ADJ_O1 3                 ADJ_O2 3                 ADJ_O3 3              
   ADJ_O4 3                 ADJ_O5 3                 ADJ_O6 3              
   ADJ_O7 3                 ADJ_O8 3                 ADJ_O9 3              
   ADJ_O10 3                ADJ_O11 3                ADJ_O12 3             
   ADJ_O13 3                ADJ_O14 3                ADJ_O15 3             
   ADJ_O16 3                ADJ_O17 3                ADJ_O18 3             
   ADJ_O19 3                ADJ_O20 3                ADJ_O21 3             
   ADJ_O22 3                ADJ_O23 3                ADJ_O24 3             
   ADJ_O25 3                ADJ_O26 3                ADJ_O27 3             
   ADJ_OHI 3                ADJ_P1 3                 ADJ_P2 3              
   ADJ_P3 3                 ADJ_P4 3                 ADJ_P5 3              
   ADJ_P6 3                 ADJ_P7 3                 ADJ_P8 3              
   ADJ_P9 3                 ADJ_P10 3                ADJ_P11 3             
   ADJ_P12 3                ADJ_P13 3                ADJ_P14 3             
   ADJ_P15 3                ADJ_P16 3                ADJ_P17 3             
   ADJ_P18 3                ADJ_P19 3                ADJ_P20 3             
   ADJ_P21 3                ADJ_P22 3                ADJ_P23 3             
   ADJ_P24 3                ADJ_P25 3                ADJ_P26 3             
   ADJ_P27 3                ADJ_PHI 3                AGGRLR1 3             
   AGGRLR2 3                AGGRLR3 3                AGGRLR4 3             
   AGGRLR5 3                AGGRLR6 3                AGGRLR7 3             
   AGGRLR8 3                AGGRLR9 3                AGGRLR10 3            
   AGGRLR11 3               AGGRLR12 3               AGGRLR13 3            
   AGGRLR14 3               AGGRLR15 3               AGGRLR16 3            
   AGGRLR17 3               AGGRLR18 3               AGGRLR19 3            
   AGGRLR20 3               AGGRLR21 3               AGGRLR22 3            
   AGGRLR23 3               AGGRLR24 3               AGGRLR25 3            
   AGGRLR26 3               AGGRLR27 3               AGGRLRHI 3            
   AGGROL1 3                AGGROL2 3                AGGROL3 3             
   AGGROL4 3                AGGROL5 3                AGGROL6 3             
   AGGROL7 3                AGGROL8 3                AGGROL9 3             
   AGGROL10 3               AGGROL11 3               AGGROL12 3            
   AGGROL13 3               AGGROL14 3               AGGROL15 3            
   AGGROL16 3               AGGROL17 3               AGGROL18 3            
   AGGROL19 3               AGGROL20 3               AGGROL21 3            
   AGGROL22 3               AGGROL23 3               AGGROL24 3            
   AGGROL25 3               AGGROL26 3               AGGROL27 3            
   AGGROLHI 3               BASADJ1 3                BASADJ2 3             
   BASADJ3 3                BASADJ4 3                BASADJ5 3             
   BASADJ6 3                BASADJ7 3                BASADJ8 3             
   BASADJ9 3                BASADJ10 3               BASADJ11 3            
   BASADJ12 3               BASADJ13 3               BASADJ14 3            
   BASADJ15 3               BASADJ16 3               BASADJ17 3            
   BASADJ18 3               BASADJ19 3               BASADJ20 3            
   BASADJ21 3               BASADJ22 3               BASADJ23 3            
   BASADJ24 3               BASADJ25 3               BASADJ26 3            
   BASADJ27 3               BASADJHI 3               BASADR1 3             
   BASADR2 3                BASADR3 3                BASADR4 3             
   BASADR5 3                BASADR6 3                BASADR7 3             
   BASADR8 3                BASADR9 3                BASADR10 3            
   BASADR11 3               BASADR12 3               BASADR13 3            
   BASADR14 3               BASADR15 3               BASADR16 3            
   BASADR17 3               BASADR18 3               BASADR19 3            
   BASADR20 3               BASADR21 3               BASADR22 3            
   BASADR23 3               BASADR24 3               BASADR25 3            
   BASADR26 3               BASADR27 3               BASADRHI 3            
   BASE1 3                  BASE2 3                  BASE3 3               
   BASE4 3                  BASE5 3                  BASE6 3               
   BASE7 3                  BASE8 3                  BASE9 3               
   BASE10 3                 BASE11 3                 BASE12 3              
   BASE13 3                 BASE14 3                 BASE15 3              
   BASE16 3                 BASE17 3                 BASE18 3              
   BASE19 3                 BASE20 3                 BASE21 3              
   BASE22 3                 BASE23 3                 BASE24 3              
   BASE25 3                 BASE26 3                 BASE27 3              
   BASEHI 3                 BASER1 3                 BASER2 3              
   BASER3 3                 BASER4 3                 BASER5 3              
   BASER6 3                 BASER7 3                 BASER8 3              
   BASER9 3                 BASER10 3                BASER11 3             
   BASER12 3                BASER13 3                BASER14 3             
   BASER15 3                BASER16 3                BASER17 3             
   BASER18 3                BASER19 3                BASER20 3             
   BASER21 3                BASER22 3                BASER23 3             
   BASER24 3                BASER25 3                BASER26 3             
   BASER27 3                BASERHI 3                FLGHTR1 3             
   FLGHTR2 3                FLGHTR3 3                FLGHTR4 3             
   FLGHTR5 3                FLGHTR6 3                FLGHTR7 3             
   FLGHTR8 3                FLGHTR9 3                FLGHTR10 3            
   FLGHTR11 3               FLGHTR12 3               FLGHTR13 3            
   FLGHTR14 3               FLGHTR15 3               FLGHTR16 3            
   FLGHTR17 3               FLGHTR18 3               FLGHTR19 3            
   FLGHTR20 3               FLGHTR21 3               FLGHTR22 3            
   FLGHTR23 3               FLGHTR24 3               FLGHTR25 3            
   FLGHTR26 3               FLGHTR27 3               FLGHTRHI 3            
   FLIGHT1 3                FLIGHT2 3                FLIGHT3 3             
   FLIGHT4 3                FLIGHT5 3                FLIGHT6 3             
   FLIGHT7 3                FLIGHT8 3                FLIGHT9 3             
   FLIGHT10 3               FLIGHT11 3               FLIGHT12 3            
   FLIGHT13 3               FLIGHT14 3               FLIGHT15 3            
   FLIGHT16 3               FLIGHT17 3               FLIGHT18 3            
   FLIGHT19 3               FLIGHT20 3               FLIGHT21 3            
   FLIGHT22 3               FLIGHT23 3               FLIGHT24 3            
   FLIGHT25 3               FLIGHT26 3               FLIGHT27 3            
   FLIGHTHI 3               MITRLR1 3                MITRLR2 3             
   MITRLR3 3                MITRLR4 3                MITRLR5 3             
   MITRLR6 3                MITRLR7 3                MITRLR8 3             
   MITRLR9 3                MITRLR10 3               MITRLR11 3            
   MITRLR12 3               MITRLR13 3               MITRLR14 3            
   MITRLR15 3               MITRLR16 3               MITRLR17 3            
   MITRLR18 3               MITRLR19 3               MITRLR20 3            
   MITRLR21 3               MITRLR22 3               MITRLR23 3            
   MITRLR24 3               MITRLR25 3               MITRLR26 3            
   MITRLR27 3               MITRLRHI 3               MITROL1 3             
   MITROL2 3                MITROL3 3                MITROL4 3             
   MITROL5 3                MITROL6 3                MITROL7 3             
   MITROL8 3                MITROL9 3                MITROL10 3            
   MITROL11 3               MITROL12 3               MITROL13 3            
   MITROL14 3               MITROL15 3               MITROL16 3            
   MITROL17 3               MITROL18 3               MITROL19 3            
   MITROL20 3               MITROL21 3               MITROL22 3            
   MITROL23 3               MITROL24 3               MITROL25 3            
   MITROL26 3               MITROL27 3               MITROLHI 3            
   OBSTRC1 3                OBSTRC2 3                OBSTRC3 3             
   OBSTRC4 3                OBSTRC5 3                OBSTRC6 3             
   OBSTRC7 3                OBSTRC8 3                OBSTRC9 3             
   OBSTRC10 3               OBSTRC11 3               OBSTRC12 3            
   OBSTRC13 3               OBSTRC14 3               OBSTRC15 3            
   OBSTRC16 3               OBSTRC17 3               OBSTRC18 3            
   OBSTRC19 3               OBSTRC20 3               OBSTRC21 3            
   OBSTRC22 3               OBSTRC23 3               OBSTRC24 3            
   OBSTRC25 3               OBSTRC26 3               OBSTRC27 3            
   OBSTRCHI 3               OBSTRR1 3                OBSTRR2 3             
   OBSTRR3 3                OBSTRR4 3                OBSTRR5 3             
   OBSTRR6 3                OBSTRR7 3                OBSTRR8 3             
   OBSTRR9 3                OBSTRR10 3               OBSTRR11 3            
   OBSTRR12 3               OBSTRR13 3               OBSTRR14 3            
   OBSTRR15 3               OBSTRR16 3               OBSTRR17 3            
   OBSTRR18 3               OBSTRR19 3               OBSTRR20 3            
   OBSTRR21 3               OBSTRR22 3               OBSTRR23 3            
   OBSTRR24 3               OBSTRR25 3               OBSTRR26 3            
   OBSTRR27 3               OBSTRRHI 3               OFFVCR1 3             
   OFFVCR2 3                OFFVCR3 3                OFFVCR4 3             
   OFFVCR5 3                OFFVCR6 3                OFFVCR7 3             
   OFFVCR8 3                OFFVCR9 3                OFFVCR10 3            
   OFFVCR11 3               OFFVCR12 3               OFFVCR13 3            
   OFFVCR14 3               OFFVCR15 3               OFFVCR16 3            
   OFFVCR17 3               OFFVCR18 3               OFFVCR19 3            
   OFFVCR20 3               OFFVCR21 3               OFFVCR22 3            
   OFFVCR23 3               OFFVCR24 3               OFFVCR25 3            
   OFFVCR26 3               OFFVCR27 3               OFFVCRHI 3            
   OFFVCT1 3                OFFVCT2 3                OFFVCT3 3             
   OFFVCT4 3                OFFVCT5 3                OFFVCT6 3             
   OFFVCT7 3                OFFVCT8 3                OFFVCT9 3             
   OFFVCT10 3               OFFVCT11 3               OFFVCT12 3            
   OFFVCT13 3               OFFVCT14 3               OFFVCT15 3            
   OFFVCT16 3               OFFVCT17 3               OFFVCT18 3            
   OFFVCT19 3               OFFVCT20 3               OFFVCT21 3            
   OFFVCT22 3               OFFVCT23 3               OFFVCT24 3            
   OFFVCT25 3               OFFVCT26 3               OFFVCT27 3            
   OFFVCTHI 3               RLADJR1 3                RLADJR2 3             
   RLADJR3 3                RLADJR4 3                RLADJR5 3             
   RLADJR6 3                RLADJR7 3                RLADJR8 3             
   RLADJR9 3                RLADJR10 3               RLADJR11 3            
   RLADJR12 3               RLADJR13 3               RLADJR14 3            
   RLADJR15 3               RLADJR16 3               RLADJR17 3            
   RLADJR18 3               RLADJR19 3               RLADJR20 3            
   RLADJR21 3               RLADJR22 3               RLADJR23 3            
   RLADJR24 3               RLADJR25 3               RLADJR26 3            
   RLADJR27 3               RLADJRHI 3               ROLADJ1 3             
   ROLADJ2 3                ROLADJ3 3                ROLADJ4 3             
   ROLADJ5 3                ROLADJ6 3                ROLADJ7 3             
   ROLADJ8 3                ROLADJ9 3                ROLADJ10 3            
   ROLADJ11 3               ROLADJ12 3               ROLADJ13 3            
   ROLADJ14 3               ROLADJ15 3               ROLADJ16 3            
   ROLADJ17 3               ROLADJ18 3               ROLADJ19 3            
   ROLADJ20 3               ROLADJ21 3               ROLADJ22 3            
   ROLADJ23 3               ROLADJ24 3               ROLADJ25 3            
   ROLADJ26 3               ROLADJ27 3               ROLADJHI 3            
   RSTRVC1 3                RSTRVC2 3                RSTRVC3 3             
   RSTRVC4 3                RSTRVC5 3                RSTRVC6 3             
   RSTRVC7 3                RSTRVC8 3                RSTRVC9 3             
   RSTRVC10 3               RSTRVC11 3               RSTRVC12 3            
   RSTRVC13 3               RSTRVC14 3               RSTRVC15 3            
   RSTRVC16 3               RSTRVC17 3               RSTRVC18 3            
   RSTRVC19 3               RSTRVC20 3               RSTRVC21 3            
   RSTRVC22 3               RSTRVC23 3               RSTRVC24 3            
   RSTRVC25 3               RSTRVC26 3               RSTRVC27 3            
   RSTRVCHI 3               RSTRVR1 3                RSTRVR2 3             
   RSTRVR3 3                RSTRVR4 3                RSTRVR5 3             
   RSTRVR6 3                RSTRVR7 3                RSTRVR8 3             
   RSTRVR9 3                RSTRVR10 3               RSTRVR11 3            
   RSTRVR12 3               RSTRVR13 3               RSTRVR14 3            
   RSTRVR15 3               RSTRVR16 3               RSTRVR17 3            
   RSTRVR18 3               RSTRVR19 3               RSTRVR20 3            
   RSTRVR21 3               RSTRVR22 3               RSTRVR23 3            
   RSTRVR24 3               RSTRVR25 3               RSTRVR26 3            
   RSTRVR27 3               RSTRVRHI 3               TEROR1 3              
   TEROR2 3                 TEROR3 3                 TEROR4 3              
   TEROR5 3                 TEROR6 3                 TEROR7 3              
   TEROR8 3                 TEROR9 3                 TEROR10 3             
   TEROR11 3                TEROR12 3                TEROR13 3             
   TEROR14 3                TEROR15 3                TEROR16 3             
   TEROR17 3                TEROR18 3                TEROR19 3             
   TEROR20 3                TEROR21 3                TEROR22 3             
   TEROR23 3                TEROR24 3                TEROR25 3             
   TEROR26 3                TEROR27 3                TERORHI 3             
   TERORR1 3                TERORR2 3                TERORR3 3             
   TERORR4 3                TERORR5 3                TERORR6 3             
   TERORR7 3                TERORR8 3                TERORR9 3             
   TERORR10 3               TERORR11 3               TERORR12 3            
   TERORR13 3               TERORR14 3               TERORR15 3            
   TERORR16 3               TERORR17 3               TERORR18 3            
   TERORR19 3               TERORR20 3               TERORR21 3            
   TERORR22 3               TERORR23 3               TERORR24 3            
   TERORR25 3               TERORR26 3               TERORR27 3            
   TERORRHI 3               USKID1 3                 USKID2 3              
   USKID3 3                 USKID4 3                 USKID5 3              
   USKID6 3                 USKID7 3                 USKID8 3              
   USKID9 3                 USKID10 3                USKID11 3             
   USKID12 3                USKID13 3                USKID14 3             
   USKID15 3                USKID16 3                USKID17 3             
   USKID18 3                USKID19 3                USKID20 3             
   USKID21 3                USKID22 3                USKID23 3             
   USKID24 3                USKID25 3                USKID26 3             
   USKID27 3                USKIDHI 3                USKIDR1 3             
   USKIDR2 3                USKIDR3 3                USKIDR4 3             
   USKIDR5 3                USKIDR6 3                USKIDR7 3             
   USKIDR8 3                USKIDR9 3                USKIDR10 3            
   USKIDR11 3               USKIDR12 3               USKIDR13 3            
   USKIDR14 3               USKIDR15 3               USKIDR16 3            
   USKIDR17 3               USKIDR18 3               USKIDR19 3            
   USKIDR20 3               USKIDR21 3               USKIDR22 3            
   USKIDR23 3               USKIDR24 3               USKIDR25 3            
   USKIDR26 3               USKIDR27 3               USKIDRHI 3            
   VCADJR1 3                VCADJR2 3                VCADJR3 3             
   VCADJR4 3                VCADJR5 3                VCADJR6 3             
   VCADJR7 3                VCADJR8 3                VCADJR9 3             
   VCADJR10 3               VCADJR11 3               VCADJR12 3            
   VCADJR13 3               VCADJR14 3               VCADJR15 3            
   VCADJR16 3               VCADJR17 3               VCADJR18 3            
   VCADJR19 3               VCADJR20 3               VCADJR21 3            
   VCADJR22 3               VCADJR23 3               VCADJR24 3            
   VCADJR25 3               VCADJR26 3               VCADJR27 3            
   VCADJRHI 3               VCTADJ1 3                VCTADJ2 3             
   VCTADJ3 3                VCTADJ4 3                VCTADJ5 3             
   VCTADJ6 3                VCTADJ7 3                VCTADJ8 3             
   VCTADJ9 3                VCTADJ10 3               VCTADJ11 3            
   VCTADJ12 3               VCTADJ13 3               VCTADJ14 3            
   VCTADJ15 3               VCTADJ16 3               VCTADJ17 3            
   VCTADJ18 3               VCTADJ19 3               VCTADJ20 3            
   VCTADJ21 3               VCTADJ22 3               VCTADJ23 3            
   VCTADJ24 3               VCTADJ25 3               VCTADJ26 3            
   VCTADJ27 3               VCTADJHI 3               VULVCR1 3             
   VULVCR2 3                VULVCR3 3                VULVCR4 3             
   VULVCR5 3                VULVCR6 3                VULVCR7 3             
   VULVCR8 3                VULVCR9 3                VULVCR10 3            
   VULVCR11 3               VULVCR12 3               VULVCR13 3            
   VULVCR14 3               VULVCR15 3               VULVCR16 3            
   VULVCR17 3               VULVCR18 3               VULVCR19 3            
   VULVCR20 3               VULVCR21 3               VULVCR22 3            
   VULVCR23 3               VULVCR24 3               VULVCR25 3            
   VULVCR26 3               VULVCR27 3               VULVCRHI 3            
   VULVCT1 3                VULVCT2 3                VULVCT3 3             
   VULVCT4 3                VULVCT5 3                VULVCT6 3             
   VULVCT7 3                VULVCT8 3                VULVCT9 3             
   VULVCT10 3               VULVCT11 3               VULVCT12 3            
   VULVCT13 3               VULVCT14 3               VULVCT15 3            
   VULVCT16 3               VULVCT17 3               VULVCT18 3            
   VULVCT19 3               VULVCT20 3               VULVCT21 3            
   VULVCT22 3               VULVCT23 3               VULVCT24 3            
   VULVCT25 3               VULVCT26 3               VULVCT27 3            
   VULVCTHI 3               LOSS12 6                 LOSS15 4              
   LOSS16 3                 LOSS17 3                 LOSS18 3              
   LOSS19 3                 LOSS20 3                 LOSS21 3              
   LOSS22 3                 LOSS23 3                 LOSS24 3              
   LOSS25 3                 LOSS26 3                 LOSS27 3              
   LOSSR7 3                 LOSSR8 6                 LOSSR9 3              
   LOSSR10 3                LOSSR11 3                LOSSR12 3             
   LOSSR13 3                LOSSR14 3                LOSSR15 3             
   LOSSR16 3                LOSSR17 3                LOSSR18 3             
   LOSSR19 3                LOSSR20 3                LOSSR21 3             
   LOSSR22 3                LOSSR23 3                LOSSR24 3             
   LOSSR25 3                LOSSR26 3                LOSSR27 3             
   CRPTS 3                  DATO4 3                  DATO5 3               
   DAFROM4 3                DAFROM5 3 ;

       

RUN ;
